@@ -13,7 +13,7 @@ namespace ARTICLE
     class ArticleViewInfo : public ArticleViewBase
     {
       public:
-        ArticleViewInfo( const std::string& url );
+        explicit ArticleViewInfo( const std::string& url );
         ~ArticleViewInfo();
 
         // viewの操作をキャンセル
@@ -27,10 +27,10 @@ namespace ARTICLE
       private:
 
         // ボタンプレスキャンセル
-        bool slot_button_press( std::string url, int res_number, GdkEventButton* event ) override { return true; }
+        bool slot_button_press( const std::string& url, int res_number, GdkEventButton* ) override { return true; }
 
         // ポップアップ表示キャンセル
-        void slot_on_url( std::string url, std::string imgurl, int res_number ) override {}
+        void slot_on_url( const std::string& url, const std::string& imgurl, int res_number ) override {}
 
         DrawAreaBase* create_drawarea() override;
     };
