@@ -253,6 +253,7 @@ namespace ARTICLE
         SIG_KEY_RELEASE sig_key_release(){ return m_sig_key_release; }
         SIG_ON_URL sig_on_url(){ return m_sig_on_url; }
         SIG_LEAVE_URL sig_leave_url(){ return m_sig_leave_url; }
+        auto sig_view_map() { return m_view.signal_map(); }
 
         explicit DrawAreaBase( const std::string& url );
         ~DrawAreaBase();
@@ -513,7 +514,7 @@ namespace ARTICLE
     //
     inline bool DrawAreaBase::is_wrapped( const int x, const int border, const char* str ) const
     {
-        const unsigned char* tmpchar = ( const unsigned char* ) str;
+        const unsigned char* tmpchar = reinterpret_cast<const unsigned char*>( str );
 
         if( x < border ) return false;
         if( ! tmpchar ) return true;
