@@ -1896,7 +1896,7 @@ void BBSListViewBase::slot_row_exp( const Gtk::TreeModel::iterator&, const Gtk::
     }
 
     m_treeview.set_cursor( path );
-    if( CONFIG::get_scroll_tree() ) m_treeview.scroll_to_row( path, 0.1 );
+    if( CONFIG::get_scroll_tree() ) m_treeview.scroll_to_row( path, 0.1f );
     show_status();
 }
 
@@ -2542,9 +2542,10 @@ void BBSListViewBase::select_item( const std::string& url )
     for( ; ! it.end(); ++it ){
 
         Gtk::TreeModel::Row row = *it;
-        Gtk::TreePath path = GET_PATH( row );
+        const Glib::ustring& ustr_url = row[ m_columns.m_url ];
 
-        if( url_item == row[ m_columns.m_url ] || url_item == path2url( path ) ){
+        if( url_item == ustr_url.raw() ){
+            Gtk::TreePath path = GET_PATH( row );
 
             // 最初に見つかったものにフォーカスする
             if( m_treeview.is_expand( path ) ){
@@ -2672,7 +2673,7 @@ void BBSListViewBase::replace_thread( const std::string& url, const std::string&
 #ifdef _DEBUG
                         std::cout << "name_row = " << ustr_name << std::endl;
 #endif
-                        if( MISC::utf8_trim( ustr_name ) == name_old ){
+                        if( MISC::utf8_trim( ustr_name.raw() ) == name_old ){
 #ifdef _DEBUG
                             std::cout << "replace name\n";
 #endif
@@ -2797,7 +2798,7 @@ void BBSListViewBase::exec_search()
         // カーソル移動
         if( hit ){
             m_treeview.expand_parents( path );
-            m_treeview.scroll_to_row( path, 0.1 );
+            m_treeview.scroll_to_row( path, 0.1f );
             m_treeview.set_cursor( path );
             show_status();
             break;
