@@ -16,6 +16,7 @@
 
 #include <gtkmm.h>
 
+#include <map>
 #include <memory>
 #include <string>
 #include <unordered_set>
@@ -87,6 +88,10 @@ namespace BBSLIST
         // スレを追加したときにそのスレにしおりを付ける
         bool m_set_bookmark{};
 
+        Glib::RefPtr<Gio::SimpleActionGroup> m_action_group;
+        Glib::RefPtr<Gtk::Builder> m_builder;
+        std::map<std::string, Gtk::Menu> m_map_popupmenu;
+
       protected:
 
         // Viewが所属するAdminクラス
@@ -209,7 +214,7 @@ namespace BBSLIST
 
         void stop() override;
         void redraw_view() override;
-        void relayout() override;  // 色やフォントなどの変更
+        void relayout( const bool completely = false ) override;  // 色やフォントなどの変更
         void focus_view() override;
         void focus_out() override;
         void close_view() override;
