@@ -83,7 +83,7 @@ SelectListDialog::SelectListDialog( Gtk::Window* parent, const std::string& url,
 
     get_content_area()->pack_start( m_label_name, Gtk::PACK_SHRINK );
     get_content_area()->pack_start( m_hbox_dirs, Gtk::PACK_SHRINK );
-    m_bt_show_tree.signal_clicked().connect( sigc::mem_fun( this, &SelectListDialog::slot_show_tree ) );
+    m_bt_show_tree.signal_clicked().connect( sigc::mem_fun( *this, &SelectListDialog::slot_show_tree ) );
 
     set_title( "お気に入り追加先選択" );
     resize( SELECTDIAG_WIDTH, 1 );
@@ -138,7 +138,7 @@ void SelectListDialog::slot_show_tree()
 
         m_selectview->set_parent_win( this );
         m_selectview->copy_treestore( m_treestore );
-        m_selectview->sig_close_dialog().connect( [this] { hide(); } );
+        m_selectview->sig_close_dialog().connect( sigc::mem_fun( *this, &SelectListDialog::hide ) );
 
         get_content_area()->pack_start( *m_selectview );
         m_selectview->set_size_request( -1, SELECTDIAG_TREEHEIGHT );
