@@ -98,6 +98,14 @@ namespace BOARD
         // 連続クリック防止用カウンタ
         int m_cancel_openrow_counter{};
 
+        // 右クリックメニュー
+        Glib::RefPtr<Gio::SimpleActionGroup> m_action_group;
+        Gtk::Menu m_popup_menu_delete;
+        Gtk::Menu m_popup_menu_favorite_article;
+        Gtk::Menu m_popup_menu_favorite;
+        Gtk::Menu m_popup_menu_mul;
+        Gtk::Menu m_popup_menu;
+
     public:
 
         BoardViewBase( const std::string& url, const bool show_col_board );
@@ -129,7 +137,7 @@ namespace BOARD
         void write() override;
         void stop() override;
         void show_view() override;
-        void relayout() override;
+        void relayout( const bool completely = false ) override;
         void focus_view() override;
         void focus_out() override;
         void close_view() override;
@@ -211,10 +219,11 @@ namespace BOARD
     private:
 
         void setup_action();
+        void setup_popupmenu( Gtk::Menu& menu, const Glib::RefPtr<Glib::Object>& model );
 
         // 通常の右クリックメニューの作成
-        std::string create_context_menu() const;
-        const char* get_menu_item( const int item ) const;
+        Glib::RefPtr<Gio::MenuModel> create_context_menu() const;
+        bool add_menu_item( const int item, const Glib::RefPtr<Gio::Menu>& section ) const;
 
         // 次スレ移行処理に使用する前スレのアドレス
         // BOARD::BoardViewNext と BoardViewBase::open_row()を参照せよ
@@ -230,6 +239,7 @@ namespace BOARD
         // 列の幅の保存
         virtual void save_column_width();
 
+        void slot_cell_data_markup( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& it );
         void slot_cell_data( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& it );
 
         // 全ての行の表示内容更新
