@@ -10,8 +10,9 @@
 
 #include "skeleton/msgdiag.h"
 
-#include "jdlib/miscutil.h"
+#include "jdlib/misccharcode.h"
 #include "jdlib/misctime.h"
+#include "jdlib/miscutil.h"
 
 #include "config/globalconf.h"
 
@@ -113,14 +114,14 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
         str_cookies = "クッキー:\n未取得\n";
     }
     else {
-        str_cookies = "クッキー:\n" + MISC::Iconv( temp_cookies, "UTF-8", DBTREE::board_charset( get_url() ) ) + "\n";
+        str_cookies = "クッキー:\n" + MISC::Iconv( temp_cookies, Encoding::utf8, DBTREE::board_encoding( get_url() ) ) + "\n";
     }
 
-    std::string keyword = DBTREE::board_keyword_for_write( get_url() );
-    if( ! keyword.empty() ) str_cookies.append( "\n書き込み用キーワード: " + keyword + "\n" );
+    const std::string& kw_write = DBTREE::board_keyword_for_write( get_url() );
+    if( ! kw_write.empty() ) str_cookies.append( "\n書き込み用キーワード: " + kw_write + "\n" );
 
-    keyword = DBTREE::board_keyword_for_newarticle( get_url() );
-    if( ! keyword.empty() ) str_cookies.append( "\nスレ立て用キーワード: " + keyword + "\n" );
+    const std::string& kw_new = DBTREE::board_keyword_for_newarticle( get_url() );
+    if( ! kw_new.empty() ) str_cookies.append( "\nスレ立て用キーワード: " + kw_new + "\n" );
 
     m_edit_cookies.set_hexpand( true );
     m_edit_cookies.set_propagate_natural_height( true );
@@ -154,10 +155,29 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     m_hbox_live.set_spacing( 4 );
     m_hbox_live.pack_start( m_label_live, Gtk::PACK_SHRINK );
     m_hbox_live.pack_start( m_spin_live, Gtk::PACK_SHRINK );
-    m_hbox_live.pack_start( m_check_live, Gtk::PACK_SHRINK );
+    m_hbox_live.pack_start( m_check_live );
 
     set_activate_entry( m_spin_live );
 
+    // テキストエンコーディング
+    const char* tmpcharset = MISC::encoding_to_cstr( DBTREE::board_encoding( get_url() ) );
+    if( CONFIG::get_choose_character_encoding() ) {
+        m_label_charset.set_text( "テキストエンコーディング : " );
+        m_combo_charset.append( MISC::encoding_to_cstr( Encoding::utf8 ) );
+        m_combo_charset.append( MISC::encoding_to_cstr( Encoding::sjis ) );
+        m_combo_charset.append( MISC::encoding_to_cstr( Encoding::eucjp ) );
+        m_combo_charset.set_active_text( tmpcharset );
+
+        m_hbox_live.pack_start( m_label_charset, Gtk::PACK_SHRINK );
+        m_hbox_live.pack_start( m_combo_charset, Gtk::PACK_SHRINK );
+    }
+    else {
+        // エンコーディング設定は安全でないので無効のときは設定欄(コンボボックス)を表示しない
+        m_label_charset.set_text( Glib::ustring::compose( "テキストエンコーディング :  %1", tmpcharset ) );
+
+        m_hbox_live.pack_start( m_label_charset, Gtk::PACK_SHRINK );
+    }
+
     // 一般ページのパッキング
     m_label_max_line.set_text( std::to_string( DBTREE::line_number( get_url() ) * 2 ) );
     m_label_max_byte.set_text( std::to_string( DBTREE::message_count( get_url() ) ) );
@@ -499,7 +519,7 @@ void Preferences::slot_ok_clicked()
     if( m_proxy_frame.rd_disable.get_active() ) mode = DBTREE::PROXY_DISABLE;
     else if( m_proxy_frame.rd_local.get_active() ) mode = DBTREE::PROXY_LOCAL;
     DBTREE::board_set_mode_local_proxy( get_url(), mode );
-    DBTREE::board_set_local_proxy( get_url(), MISC::utf8_trim( m_proxy_frame.entry_host.get_text() ) );
+    DBTREE::board_set_local_proxy( get_url(), MISC::utf8_trim( m_proxy_frame.entry_host.get_text().raw() ) );
     DBTREE::board_set_local_proxy_port( get_url(), atoi( m_proxy_frame.entry_port.get_text().c_str() ) );
 
     mode = DBTREE::PROXY_GLOBAL;
@@ -507,7 +527,7 @@ void Preferences::slot_ok_clicked()
     else if( m_proxy_frame_w.rd_local.get_active() ) mode = DBTREE::PROXY_LOCAL;
 
     DBTREE::board_set_mode_local_proxy_w( get_url(), mode );
-    DBTREE::board_set_local_proxy_w( get_url(), MISC::utf8_trim( m_proxy_frame_w.entry_host.get_text() ) );
+    DBTREE::board_set_local_proxy_w( get_url(), MISC::utf8_trim( m_proxy_frame_w.entry_host.get_text().raw() ) );
     DBTREE::board_set_local_proxy_port_w( get_url(), atoi( m_proxy_frame_w.entry_port.get_text().c_str() ) );
 
     // 書き込み設定
@@ -523,6 +543,12 @@ void Preferences::slot_ok_clicked()
     else if( tmpmail.empty() ) tmpmail = JD_MAIL_BLANK; // 空白の場合 JD_MAIL_BLANK をセットする
     DBTREE::board_set_write_mail( get_url(), tmpmail );
 
+    // charset
+    if( m_combo_charset.get_mapped() ) {
+        const std::string tmpcharset = m_combo_charset.get_active_text();
+        DBTREE::board_set_encoding( get_url(), MISC::encoding_from_sv( tmpcharset ) );
+    }
+
     // 実況間隔
     int live_sec = 0;
     if( m_check_live.get_active() ) live_sec = m_spin_live.get_value_as_int();
