@@ -149,6 +149,12 @@ bool ConfigItems::load( const bool restore )
     // ipv6使用
     use_ipv6 = cf.get_option_bool( "use_ipv6", CONF_USE_IPV6 );
 
+    // TLSでノンブロッキングI/Oを使用する
+    tls_nonblocking = cf.get_option_bool( "tls_nonblocking", CONF_TLS_NONBLOCKING );
+
+    // TLSでサーバー証明書を検証する (unsafe to turn off)
+    verify_cert = cf.get_option_bool( "verify_cert", CONF_VERIFY_CERT );
+
     // 同一ホストに対する最大コネクション数( 1 または 2 )
     connection_num = cf.get_option_int( "connection_num", CONF_CONNECTION_NUM, 1, 2 );
 
@@ -270,6 +276,9 @@ bool ConfigItems::load( const bool restore )
     // スレビューの選択色でgtkrcの設定を使用するか
     use_select_gtkrc = cf.get_option_bool( "use_select_gtkrc", CONF_USE_SELECT_GTKRC );
 
+    // スレビューでHTMLタグ指定の色を使用するか
+    use_color_html = cf.get_option_bool( "use_color_html", CONF_USE_COLOR_HTML );
+
     // ツリービューの行間スペース
     tree_ypad = cf.get_option_int( "tree_ypad", CONF_TREE_YPAD, 0, 64 );
 
@@ -446,6 +455,9 @@ bool ConfigItems::load( const bool restore )
     // datのパース時にURL判定を甘くする(^なども含める)
     loose_url = cf.get_option_bool( "loose_url", CONF_LOOSE_URL );
 
+    // URLのパーセントエンコーディングをデコードして表示する
+    percent_decode = cf.get_option_bool( "percent_decode", CONF_PERCENT_DECODE );
+
     // ユーザーコマンドで選択できない項目を非表示にする
     hide_usrcmd = cf.get_option_bool( "hide_usrcmd", CONF_HIDE_USRCMD );
 
@@ -591,9 +603,15 @@ bool ConfigItems::load( const bool restore )
     migemodict_path = cf.get_option_str( "migemodict_path", CONF_MIGEMO_PATH );
 #endif
 
+    // 不正なMS932文字列をUTF-8と見なす
+    broken_sjis_be_utf8 = cf.get_option_bool( "broken_sjis_be_utf8", CONF_BROKEN_SJIS_BE_UTF8 );
+
     // 不正な数値文字参照(サロゲートペア)をデコードする
     correct_character_reference = cf.get_option_bool( "correct_character_reference", CONF_CORRECT_CHAR_REFERENCE );
 
+    // スレ一覧とスレビューのプロパティにあるエンコーディング設定を有効にする (unsafe)
+    choose_character_encoding = cf.get_option_bool( "choose_character_encoding", CONF_CHOOSE_CHAR_ENCODING );
+
     m_loaded = true;
 
     // 設定値に壊れている物がある
@@ -710,6 +728,8 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "loader_timeout_checkupdate", loader_timeout_checkupdate );
 
     cf.update( "use_ipv6", use_ipv6 );
+    cf.update( "tls_nonblocking", tls_nonblocking );
+    cf.update( "verify_cert", verify_cert );
     cf.update( "connection_num", connection_num );
 
     cf.update( "use_cookie_hap", use_cookie_hap );
@@ -785,6 +805,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "use_message_gtktheme", use_message_gtktheme );
     cf.update( "use_tree_gtkrc", use_tree_gtkrc );
     cf.update( "use_select_gtkrc", use_select_gtkrc );
+    cf.update( "use_color_html", use_color_html );
 
     cf.update( "tree_ypad", tree_ypad );
     cf.update( "tree_show_expanders", tree_show_expanders );
@@ -859,6 +880,8 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "loose_url", loose_url );
 
+    cf.update( "percent_decode", percent_decode );
+
     cf.update( "hide_usrcmd", hide_usrcmd );
     cf.update( "reload_allthreads", reload_allthreads );
 
@@ -936,7 +959,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "migemodict_path", migemodict_path );
 #endif
 
+    cf.update( "broken_sjis_be_utf8", broken_sjis_be_utf8 );
     cf.update( "correct_character_reference", correct_character_reference );
+    cf.update( "choose_character_encoding", choose_character_encoding );
 
     cf.save();
 }
