@@ -90,6 +90,12 @@ namespace CONFIG
         // ipv6使用
         bool use_ipv6{};
 
+        /// TLSでノンブロッキングI/Oを使用する
+        bool tls_nonblocking{};
+
+        /// TLSでサーバー証明書を検証する (unsafe to turn off)
+        bool verify_cert{};
+
         // 同一ホストに対する最大コネクション数( 1 または 2 )
         int connection_num{};
 
@@ -223,6 +229,9 @@ namespace CONFIG
         // スレビューの選択色でgtkrcの設定を使用するか
         bool use_select_gtkrc{};
 
+        /// スレビューでHTMLタグ指定の色を使用するか
+        bool use_color_html{};
+
         // ツリービューの行間スペース
         int tree_ypad{};
 
@@ -399,6 +408,9 @@ namespace CONFIG
         // datのパース時にURL判定を甘くする(^なども含める)
         bool loose_url{};
 
+        /// URLのパーセントエンコーディングをデコードして表示する
+        bool percent_decode{};
+
         // ユーザーコマンドで選択できない項目を非表示にする
         bool hide_usrcmd{};
 
@@ -536,9 +548,15 @@ namespace CONFIG
         std::string migemodict_path;
 #endif
 
+        /// 不正なMS932文字列をUTF-8と見なす
+        bool broken_sjis_be_utf8{};
+
         /// 不正な数値文字参照(サロゲートペア)をデコードする
         bool correct_character_reference{};
 
+        /// スレ一覧とスレビューのプロパティにあるエンコーディング設定を有効にする (unsafe)
+        bool choose_character_encoding{};
+
         /////////////////////////
 
 
