@@ -97,6 +97,9 @@ void CONFIG::set_use_tree_gtkrc( const bool use ){ get_confitem()->use_tree_gtkr
 bool CONFIG::get_use_select_gtkrc(){ return get_confitem()->use_select_gtkrc; }
 void CONFIG::set_use_select_gtkrc( const bool use ){ get_confitem()->use_select_gtkrc = use; }
 
+bool CONFIG::get_use_color_html(){ return get_confitem()->use_color_html; }
+void CONFIG::set_use_color_html( const bool use ){ get_confitem()->use_color_html = use; }
+
 // ツリービューの行間スペース
 int CONFIG::get_tree_ypad(){ return get_confitem()->tree_ypad; }
 
@@ -229,6 +232,11 @@ int CONFIG::get_loader_timeout_checkupdate(){ return get_confitem()->loader_time
 bool CONFIG::get_use_ipv6(){ return get_confitem()->use_ipv6; }
 void CONFIG::set_use_ipv6( const bool set ){ get_confitem()->use_ipv6 = set; }
 
+// TLSでノンブロッキングI/Oを使用する
+bool CONFIG::get_tls_nonblocking(){ return get_confitem()->tls_nonblocking; }
+// TLSでサーバー証明書を検証する (unsafe to turn off)
+bool CONFIG::get_verify_cert(){ return get_confitem()->verify_cert; }
+
 // 同一ホストに対する最大コネクション数( 1 または 2 )
 int CONFIG::get_connection_num(){ return get_confitem()->connection_num; }
 
@@ -435,6 +443,8 @@ int CONFIG::get_num_id_low(){ return get_confitem()->num_id_low; }
 
 bool CONFIG::get_loose_url(){ return get_confitem()->loose_url; }
 
+bool CONFIG::get_percent_decode(){ return get_confitem()->percent_decode; }
+
 bool CONFIG::get_hide_usrcmd(){ return get_confitem()->hide_usrcmd; }
 void CONFIG::set_hide_usrcmd( const bool hide ){ get_confitem()->hide_usrcmd = hide; }
 
@@ -620,9 +630,22 @@ int CONFIG::get_save_session(){ return get_confitem()->save_session; }
 const std::string& CONFIG::get_migemodict_path() { return get_confitem()->migemodict_path; }
 #endif
 
+// 不正なMS932文字列をUTF-8と見なす
+bool CONFIG::get_broken_sjis_be_utf8(){
+    auto item = get_confitem();
+    return item ? item->broken_sjis_be_utf8 : false;
+}
+void CONFIG::set_broken_sjis_be_utf8( const bool set ){ get_confitem()->broken_sjis_be_utf8 = set; }
+
 // 不正な数値文字参照(サロゲートペア)をデコードする
 bool CONFIG::get_correct_character_reference(){
     auto item = get_confitem();
     return item ? item->correct_character_reference : false;
 }
 void CONFIG::set_correct_character_reference( const bool set ){ get_confitem()->correct_character_reference = set; }
+
+// スレ一覧とスレビューのプロパティにあるエンコーディング設定を有効にする (unsafe)
+bool CONFIG::get_choose_character_encoding(){
+    auto item = get_confitem();
+    return item ? item->choose_character_encoding : false;
+}
