@@ -56,6 +56,10 @@ namespace CONFIG
     bool get_use_select_gtkrc();
     void set_use_select_gtkrc( const bool use );
 
+    // スレビューでHTMLタグ指定の色を使用するか
+    bool get_use_color_html();
+    void set_use_color_html( const bool use );
+
     // ツリービューの行間スペース
     int get_tree_ypad();
 
@@ -195,6 +199,12 @@ namespace CONFIG
     bool get_use_ipv6();
     void set_use_ipv6( const bool set );
 
+    /// TLSでノンブロッキングI/Oを使用する
+    bool get_tls_nonblocking();
+
+    /// TLSでサーバー証明書を検証する (unsafe to turn off)
+    bool get_verify_cert();
+
     // 同一ホストに対する最大コネクション数( 1 または 2 )
     int get_connection_num();
 
@@ -457,6 +467,9 @@ namespace CONFIG
     // datのパース時にURL判定を甘くする(^なども含める)
     bool get_loose_url();
 
+    /// URLのパーセントエンコーディングをデコードして表示する
+    bool get_percent_decode();
+
     // ユーザーコマンドで選択できない項目を非表示にする
     bool get_hide_usrcmd();
     void set_hide_usrcmd( const bool hide );
@@ -617,9 +630,16 @@ namespace CONFIG
     const std::string& get_migemodict_path();
 #endif
 
+    // 不正なMS932文字列をUTF-8と見なす
+    bool get_broken_sjis_be_utf8();
+    void set_broken_sjis_be_utf8( const bool set );
+
     // 不正な数値文字参照(サロゲートペア)をデコードする
     bool get_correct_character_reference();
     void set_correct_character_reference( const bool set );
+
+    // スレ一覧とスレビューのプロパティにあるエンコーディング設定を有効にする (unsafe)
+    bool get_choose_character_encoding();
 }
 
 
