@@ -98,7 +98,7 @@ void MouseConfig::set_one_motion_impl( const int id, const int mode, const std::
 
 
 // 操作文字列取得
-std::string MouseConfig::get_str_motions( const int id_ )
+std::string MouseConfig::get_str_motions( const int id_ ) const
 {
     int id = id_;
 
@@ -110,7 +110,7 @@ std::string MouseConfig::get_str_motions( const int id_ )
 
 
 // IDからデフォルトの操作文字列取得
-std::string MouseConfig::get_default_motions( const int id_ )
+std::string MouseConfig::get_default_motions( const int id_ ) const
 {
     int id = id_;
     if( id == CONTROL::CancelMosaic ) id = CONTROL::CancelMosaicButton;
