@@ -13,7 +13,9 @@
 #include "colorid.h"
 #include "cache.h"
 
+#include <cmath>
 #include <cstring>
+#include <limits>
 
 enum
 {
@@ -94,7 +96,7 @@ std::string Css_Manager::get_color( int colorid ) const
 //
 // クラス名からID取得
 //
-int Css_Manager::get_classid( const std::string& classname ) const
+int Css_Manager::get_classid( std::string_view classname ) const
 {
     int id = 0;
 
@@ -523,6 +525,19 @@ CSS_PROPERTY Css_Manager::get_property( const int id )
 }
 
 
+/** @brief CSS プロパティのconst参照を取得する
+ *
+ * @details CSS_PROPERTY の構造体はサイズが大きいため参照を返すことでコピーを回避できる。
+ * @param[in] id register_class() で登録したCSS classのID
+ * @return CSS プロパティのconst参照
+ * @throw std::out_of_range 存在しないIDを指定すると例外が発生する
+ */
+const CSS_PROPERTY& Css_Manager::get_property( const int id ) const
+{
+    return m_css.at( id );
+}
+
+
 //
 // プロパティをセット
 //
@@ -549,7 +564,8 @@ void Css_Manager::set_property( const std::string& classname, const CSS_PROPERTY
 void Css_Manager::set_size( CSS_PROPERTY* css, double height ) const
 {
     if( ! css ) return;
-    if( ! height ) return;
+    // 誤差を考慮した height == 0
+    if( std::abs( height ) < std::numeric_limits<double>::epsilon() ) return;
 
     css->padding_left = 0;
     css->padding_right = 0;
