@@ -9,10 +9,11 @@
 
 #include "skeleton/msgdiag.h"
 
-#include "jdlib/miscutil.h"
-#include "jdlib/misctime.h"
-#include "jdlib/miscmsg.h"
 #include "jdlib/jdregex.h"
+#include "jdlib/misccharcode.h"
+#include "jdlib/miscmsg.h"
+#include "jdlib/misctime.h"
+#include "jdlib/miscutil.h"
 #include "jdlib/tfidf.h"
 
 #include "dbimg/imginterface.h"
@@ -63,11 +64,12 @@ if( it2 != lines.end() ){ \
 
 
 
-ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, bool cached )
+ArticleBase::ArticleBase( const std::string& datbase, const std::string& id, bool cached, const Encoding enc )
     : SKELETON::Lockable()
     , m_id( id )
     , m_code( HTTP_INIT )
     , m_status( STATUS_UNKNOWN )
+    , m_encoding( enc )
     , m_abone_board( true )
     , m_abone_global( true )
     , m_cached( cached )
@@ -1924,6 +1926,15 @@ void ArticleBase::read_info()
         GET_INFOVALUE( str_tmp, "status = " );
         if( ! str_tmp.empty() ) m_status = atoi( str_tmp.c_str() );
 
+        // charset
+        GET_INFOVALUE( str_tmp, "charset = " );
+        if( ! str_tmp.empty() ) {
+            if( const Encoding enc = MISC::encoding_from_sv( str_tmp );
+                    enc != Encoding::unknown ) {
+                set_encoding( enc );
+            }
+        }
+
         // あぼーん ID
         GET_INFOVALUE( str_tmp, "aboneid = " );
         if( ! str_tmp.empty() ) m_list_abone_id = MISC::strtolist( str_tmp );
@@ -2090,6 +2101,7 @@ void ArticleBase::read_info()
               << "writefixname = " << m_write_fixname << std::endl
               << "writefixmail = " << m_write_fixmail << std::endl
               << "status = " << m_status << std::endl
+              << "encoding = " << MISC::encoding_to_cstr( get_encoding() ) << std::endl
               << "transparent_abone = " << m_abone_transparent << std::endl
               << "bookmarked_thread = " << m_bookmarked_thread << std::endl
     ;
@@ -2217,6 +2229,7 @@ void ArticleBase::save_info( const bool force )
          << "writefixname = " << m_write_fixname << std::endl
          << "writefixmail = " << m_write_fixmail << std::endl
          << "status = " << m_status << std::endl
+         << "charset = " << MISC::encoding_to_cstr( get_encoding() ) << std::endl
          << "aboneid = " << str_abone_id << std::endl
          << "abonename = " << str_abone_name << std::endl
          << "bookmark = " << ss_bookmark.str() << std::endl
