@@ -6,8 +6,10 @@
 #include "articlehash.h"
 #include "articlebase.h"
 
+#include <algorithm>
 #include <stdlib.h> // atoi
 
+
 using namespace DBTREE;
 
 
@@ -20,7 +22,6 @@ enum
 ArticleHash::ArticleHash()
     : m_min_hash( HASH_TBLSIZE + 1 )
 {
-    m_iterator = new ArticleHashIterator( this );
 }
 
 
@@ -36,13 +37,10 @@ ArticleHash::~ArticleHash()
         }
     }
 #endif
-
-    if( m_iterator ) delete m_iterator;
-    m_iterator = nullptr;
 }
 
 
-int ArticleHash::get_hash( const std::string& id )
+int ArticleHash::get_hash( const std::string& id ) const
 {
     const size_t hash = atoi( id.c_str() ) & ( HASH_TBLSIZE -1 );
 
@@ -54,7 +52,7 @@ int ArticleHash::get_hash( const std::string& id )
 }
 
 
-void ArticleHash::push( ArticleBase* article )
+ArticleBase* ArticleHash::insert( std::unique_ptr<ArticleBase> article )
 {
     if( ! m_table.size() ){
         m_table.resize( HASH_TBLSIZE );
@@ -64,7 +62,8 @@ void ArticleHash::push( ArticleBase* article )
 
     if( hash < m_min_hash ) m_min_hash = hash;
     ++m_size;
-    m_table[ hash ].push_back( article );
+    m_table[ hash ].push_back( std::move( article ) );
+    return m_table[ hash ].back().get();
 }
 
 
@@ -74,8 +73,10 @@ ArticleBase* ArticleHash::find( const std::string& datbase, const std::string& i
 
     const size_t hash = get_hash( id );
 
-    std::vector< ArticleBase* >::iterator it = m_table[ hash ].begin();
-    for( ; it != m_table[ hash ].end(); ++it ) if( ( *it )->equal( datbase, id ) ) return *it;
+    auto& block = m_table[ hash ];
+    auto it = std::find_if( block.begin(), block.end(),
+                            [&datbase, &id]( auto& a ) { return a->equal( datbase, id ); } );
+    if( it != block.end() ) return it->get();
 
     return nullptr;
 }
@@ -87,7 +88,7 @@ ArticleHashIterator ArticleHash::begin()
     m_it_pos = 0;
     m_it_size = 0;
 
-    return *m_iterator;
+    return ArticleHashIterator{ this };
 }
 
 
@@ -95,7 +96,7 @@ ArticleBase* ArticleHash::it_get()
 {
     if( m_it_hash >= m_table.size() ) return nullptr;
 
-    return m_table[ m_it_hash ][ m_it_pos ];
+    return m_table[ m_it_hash ][ m_it_pos ].get();
 }
 
 
