@@ -17,7 +17,7 @@ namespace DBTREE
     {
       public:
 
-        ArticleMachi( const std::string& datbase, const std::string& id, bool cached );
+        ArticleMachi( const std::string& datbase, const std::string& id, bool cached, const Encoding enc );
         ~ArticleMachi() noexcept;
 
         // 書き込みメッセージ変換
