@@ -158,7 +158,7 @@ std::string DBTREE::is_board_moved( const std::string& url,
 
 bool DBTREE::move_board( const std::string& url_old, const std::string& url_new )
 {
-    return get_root()->move_board( url_old, url_new, false );
+    return get_root()->move_board( url_old, url_new );
 }
 
 void DBTREE::set_enable_save_movetable( const bool set )
@@ -218,7 +218,7 @@ void DBTREE::download_bbsmenu()
 
 
 // bbsmenuの更新時間( 文字列 )
-std::string DBTREE::get_date_modified()
+const std::string& DBTREE::get_date_modified()
 {
     return get_root()->get_date_modified();
 }
@@ -231,13 +231,13 @@ time_t DBTREE::get_time_modified()
 }
 
 
-std::string DBTREE::board_path( const std::string& url )
+const std::string& DBTREE::board_path( const std::string& url )
 {
     return DBTREE::get_board( url )->get_path_board();
 }
 
 
-std::string DBTREE::board_id( const std::string& url )
+const std::string& DBTREE::board_id( const std::string& url )
 {
     return DBTREE::get_board( url )->get_id();
 }
@@ -249,7 +249,7 @@ time_t DBTREE::board_time_modified( const std::string& url )
 }
 
 // 板の更新時間( 文字列 )
-std::string DBTREE::board_date_modified( const std::string& url )
+const std::string& DBTREE::board_date_modified( const std::string& url )
 {
     return DBTREE::get_board( url )->get_date_modified();
 }
@@ -281,21 +281,27 @@ void DBTREE::board_set_modified_setting( const std::string& url, const std::stri
 }
 
 
-std::string DBTREE::board_name( const std::string& url )
+const std::string& DBTREE::board_name( const std::string& url )
 {
     return DBTREE::get_board( url )->get_name();
 }
 
 
-std::string DBTREE::board_subjecttxt( const std::string& url )
+const std::string& DBTREE::board_subjecttxt( const std::string& url )
 {
     return DBTREE::get_board( url )->get_subjecttxt();
 }
 
 
-std::string DBTREE::board_charset( const std::string& url )
+Encoding DBTREE::board_encoding( const std::string& url )
 {
-    return DBTREE::get_board( url )->get_charset();
+    return DBTREE::get_board( url )->get_encoding();
+}
+
+
+void DBTREE::board_set_encoding( const std::string& url, const Encoding enc )
+{
+    return DBTREE::get_board( url )->set_encoding( enc );
 }
 
 
@@ -327,7 +333,7 @@ void DBTREE::board_delete_cookies( const std::string& url )
     DBTREE::get_board( url )->delete_cookies();
 }
 
-std::string DBTREE::board_keyword_for_write( const std::string& url )
+const std::string& DBTREE::board_keyword_for_write( const std::string& url )
 {
     return DBTREE::get_board( url )->get_keyword_for_write();
 }
@@ -345,7 +351,7 @@ void DBTREE::board_analyze_keyword_for_write( const std::string& url, const std:
 }
 
 
-std::string DBTREE::board_keyword_for_newarticle( const std::string& url )
+const std::string& DBTREE::board_keyword_for_newarticle( const std::string& url )
 {
     return DBTREE::get_board( url )->get_keyword_for_newarticle();
 }
@@ -369,13 +375,13 @@ std::string DBTREE::board_parse_form_data( const std::string& url, const std::st
 }
 
 
-std::string DBTREE::board_basicauth( const std::string& url )
+const std::string& DBTREE::board_basicauth( const std::string& url )
 {
     return DBTREE::get_board( url )->get_basicauth();
 }
 
 
-std::string DBTREE::board_ext( const std::string& url )
+const std::string& DBTREE::board_ext( const std::string& url )
 {
     return DBTREE::get_board( url )->get_ext();
 }
@@ -393,7 +399,7 @@ int DBTREE::board_code( const std::string& url )
 }
 
 
-std::string DBTREE::board_str_code( const std::string& url )
+const std::string& DBTREE::board_str_code( const std::string& url )
 {
     return DBTREE::get_board( url )->get_str_code();
 }
@@ -837,21 +843,21 @@ bool DBTREE::article_is_cached( const std::string& url )
 
 
 // 拡張子付き
-std::string DBTREE::article_id( const std::string& url )
+const std::string& DBTREE::article_id( const std::string& url )
 {
     return DBTREE::get_article( url )->get_id();
 }
 
 
 // idから拡張子を取ったもの
-std::string DBTREE::article_key( const std::string& url )
+const std::string& DBTREE::article_key( const std::string& url )
 {
     return DBTREE::get_article( url )->get_key();
 }
 
 
 // 移転する前のオリジナルのURL
-std::string DBTREE::article_org_host( const std::string& url )
+const std::string& DBTREE::article_org_host( const std::string& url )
 {
     return DBTREE::get_article( url )->get_org_host();
 }
@@ -877,7 +883,7 @@ time_t DBTREE::article_time_modified( const std::string& url )
 
 
 // スレの更新時間( 文字列 )
-std::string DBTREE::article_date_modified( const std::string& url )
+const std::string& DBTREE::article_date_modified( const std::string& url )
 {
     return DBTREE::get_article( url )->get_date_modified();
 }
@@ -888,7 +894,19 @@ void DBTREE::article_set_date_modified( const std::string& url, const std::strin
     DBTREE::get_article( url )->set_date_modified( date );
 }
 
-int  DBTREE::article_hour( const std::string& url )
+// スレの文字コード
+Encoding DBTREE::article_encoding( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_encoding();
+}
+
+// スレの文字コードをセット
+void DBTREE::article_set_encoding( const std::string& url, const Encoding enc )
+{
+    DBTREE::get_article( url )->set_encoding( enc );
+}
+
+int DBTREE::article_hour( const std::string& url )
 {
     return DBTREE::get_article( url )->get_hour();
 }
@@ -918,12 +936,12 @@ int DBTREE::article_code( const std::string& url )
     return DBTREE::get_article( url )->get_code();
 }
 
-std::string DBTREE::article_str_code( const std::string& url )
+const std::string& DBTREE::article_str_code( const std::string& url )
 {
     return DBTREE::get_article( url )->get_str_code();
 }
 
-std::string DBTREE::article_ext_err( const std::string& url )
+const std::string& DBTREE::article_ext_err( const std::string& url )
 {
     return DBTREE::get_article( url )->get_ext_err();
 }
