@@ -29,11 +29,9 @@ namespace DBTREE
         NODE_DIV,   // div
         NODE_IMG,   // img
 
-        // スペース(幅0)
-        NODE_ZWSP,
-
-        // 連続半角スペース
-        NODE_MULTISP,
+        NODE_SP,    // スペース
+        NODE_ZWSP,  // スペース(幅0)
+        NODE_MULTISP, // 連続半角スペース
 
         // 水平タブ(0x09)
         NODE_HTAB,
@@ -117,6 +115,7 @@ namespace DBTREE
         
         char* text;
         unsigned char color_text; // 色
+        unsigned char color_back; ///< 背景色
         bool bold;
         char fontid; // fontid.h
         
