@@ -16,16 +16,16 @@
 #include "session.h"
 #include "login2ch.h"
 
+#include <cstdlib>
 #include <sstream>
 
+
 using namespace DBTREE;
 
 
 enum
 {
     MODE_NORMAL = 0,
-    MODE_OFFLAW,
-    MODE_KAKO_GZ,
     MODE_KAKO,
     MODE_OLDURL
 };
@@ -61,31 +61,9 @@ NodeTree2ch::~NodeTree2ch()
 //
 // 先頭にrawモードのステータスが入っていたら取り除く
 //
-char* NodeTree2ch::process_raw_lines( char* rawlines )
+char* NodeTree2ch::process_raw_lines( std::string& rawlines )
 {
-    char* pos = rawlines;
-
-    if( m_mode == MODE_OFFLAW ){
-        // rokka独自のステータスが入っている
-
-        int status = 0;
-        if( strncmp( pos, "Success", 7 ) == 0 ) status = 1;
-        if( strncmp( pos, "Error", 5 ) == 0 ) status = 2;
-
-#ifdef _DEBUG
-        std::cout << "NodeTree2ch::process_raw_lines : raw mode status = " << status << std::endl;
-#endif
-
-        if( status != 0 ){
-            pos = skip_status_line( pos, status );
-        }
-    }
-
-    else {
-        pos = NodeTree2chCompati::process_raw_lines( rawlines );
-    }
-
-    return pos;
+    return NodeTree2chCompati::process_raw_lines( rawlines );
 }
 
 
@@ -140,8 +118,10 @@ void NodeTree2ch::create_loaderdata( JDLIB::LOADERDATA& data )
     data.url = std::string();
     data.byte_readfrom = 0;
 
-    //rokka使用 (旧offlaw, offlaw2は廃止)
-    if( m_mode == MODE_OFFLAW ){
+    // ( rokka, 旧offlaw, offlaw2は廃止 )
+    // DAT落ちした現役サーバに収容されているスレッド
+    // または旧URL(過去ログサーバ)に収容されているスレッド
+    if( m_mode == MODE_KAKO || m_mode == MODE_OLDURL ) {
 
         JDLIB::Regex regex;
         const size_t offset = 0;
@@ -150,68 +130,39 @@ void NodeTree2ch::create_loaderdata( JDLIB::LOADERDATA& data )
         const bool usemigemo = false;
         const bool wchar = false;
 
-        if( ! regex.exec( "(https?://)([^/\\.]+)(\\.[^/]+)(/.*)/dat(/.*)\\.dat$", m_org_url, offset, icase, newline, usemigemo, wchar ) ) return;
+        const std::string& url = ( m_mode == MODE_OLDURL ) ? m_org_url : get_url();
+
+        if( ! regex.exec( "(https?://[^/]*)(/.*)/dat(/.*)\\.dat$", url, offset, icase, newline, usemigemo, wchar ) ) return;
+        const int id = std::atoi( regex.str( 3 ).c_str() + 1 );
 
-        // http://rokka(.2ch.net|.bbspink.com)/<SERVER NAME>/<BOARD NAME>/<DAT NUMBER>/<OPTIONS>?sid=<SID>
         std::ostringstream ss;
-        ss << regex.str( 1 ) << "rokka" << regex.str( 3 ) << "/" << regex.str( 2 )
-           << regex.str( 4 ) << regex.str( 5 );
 
-        std::string sid = CORE::get_login2ch()->get_sessionid();
-        ss << "/?sid=" << MISC::url_encode( sid.c_str(), sid.length() );
+        // 過去ログURLの構築
+        // スレIDが10桁の場合 -> https://サーバ/板ID/oyster/IDの上位4桁/ID.dat
+        // スレIDが 9桁の場合 -> https://サーバ/板ID/oyster/IDの上位3桁/ID.dat
+        ss << regex.str( 1 ) << regex.str( 2 ) << "/oyster/" << ( id / 1000000 ) << regex.str( 3 ) << ".dat";
 
         // レジューム設定
-        // レジュームを有りにして、サーバが range を無視して送ってきた場合と同じ処理をする
-        if( get_lng_dat() ) {
-            set_resume( true );
-        }
-        else set_resume( false );
+        // DATを読み込んでいた場合はレジュームを有りにして、DATの未取得部分を追加するように処理する
+        set_resume( get_lng_dat() > 0 );
 
         data.url = ss.str();
     }
 
-    // 過去ログ倉庫使用
-    else if( m_mode == MODE_KAKO_GZ || m_mode == MODE_KAKO ){
-
-        JDLIB::Regex regex;
-        const size_t offset = 0;
-        const bool icase = false;
-        const bool newline = true;
-        const bool usemigemo = false;
-        const bool wchar = false;
-
-        if( ! regex.exec( "(https?://[^/]*)(/.*)/dat(/.*)\\.dat$", m_org_url, offset, icase, newline, usemigemo, wchar ) ) return;
-        const int id = atoi( regex.str( 3 ).c_str() + 1 );
-
-        std::ostringstream ss;
-
-        // スレIDが10桁の場合 → http://サーバ/板ID/kako/IDの上位4桁/IDの上位5桁/ID.dat.gz
-        if( id / 1000000000 ) ss << regex.str( 1 ) << regex.str( 2 ) << "/kako/" << ( id / 1000000 ) << "/" << ( id / 100000 ) << regex.str( 3 );
-
-        // スレIDが9桁の場合 → http://サーバ/板ID/kako/IDの上位3桁/ID.dat.gz
-        else ss << regex.str( 1 ) << regex.str( 2 ) << "/kako/" << ( id / 1000000 ) << regex.str( 3 );
-
-        if( m_mode == MODE_KAKO_GZ ) ss << ".dat.gz";
-        else ss << ".dat";
-
-        // レジュームは無し
-        set_resume( false );
-
-        data.url = ss.str();
-    }
-
-    // 普通もしくは旧URLからの読み込み
+    // 普通の読み込み
     else{
 
         // レジューム設定
         // 1byte前からレジュームして '\n' が返ってこなかったらあぼーんがあったってこと
         if( get_lng_dat() ) {
             data.byte_readfrom = get_lng_dat() -1;
+            // 更新チェックのときは未取得の範囲を指定する
+            if( is_checking_update() ) data.byte_readfrom += 1;
             set_resume( true );
         }
         else set_resume( false );
 
-        data.url = ( m_mode == MODE_OLDURL ) ? m_org_url : get_url();
+        data.url = get_url();
     }
 
 #ifdef _DEBUG    
@@ -247,64 +198,36 @@ void NodeTree2ch::receive_finish()
               << "mode = " << m_mode << " code = " << get_code() << std::endl;
 #endif
 
-    // 更新チェックではない、オンラインの場合は offlaw や 過去ログ倉庫から取得出来るか試みる
+    // 更新チェックではない、オンラインの場合は過去ログ倉庫から取得出来るか試みる
     if( ! is_checking_update()
         && SESSION::is_online()
-        && ( get_code() == HTTP_REDIRECT || get_code() == HTTP_MOVED_PERM || get_code() == HTTP_NOT_FOUND
-             || ( m_mode == MODE_OFFLAW && ! get_ext_err().empty() ) // rokka 読み込み失敗
-            )
+        && ( get_code() == HTTP_REDIRECT || get_code() == HTTP_MOVED_PERM || get_code() == HTTP_NOT_FOUND )
         ){
 
 /*
+        DATファイルへのアクセス方法 ( 2023-07-11 からの仕様 )
+        参考文献: https://agree.5ch.net/test/read.cgi/operate/9240230711/3
 
-  ・スレIDが10桁の場合 → http://サーバ/板ID/kako/IDの上位4桁/IDの上位5桁/ID.dat.gz
+        ・スレIDが10桁の場合 -> https://サーバ/板ID/oyster/IDの上位4桁/ID.dat
 
-  (例) http://HOGE.2ch.net/test/read.cgi/hoge/1234567890/ を取得
+        (例) https://HOGE.5ch.net/test/read.cgi/hoge/1234567890/ を取得
+        (1) https://HOGE.5ch.net/hoge/dat/1234567890.dat から DAT を取得。
+        (2) https://HOGE.5ch.net/hoge/oyster/1234/1234567890.dat から取得。
+        (3) 旧URL(過去ログサーバ)がある場合、そのURLで再取得
 
-  (1) http://HOGE.2ch.net/hoge/dat/1234567890.dat から dat を取得。302で●がある場合(2-1)、旧URLがある場合(2-2)、無い場合は(2-3)へ(※)
-
-  (2-1) offlaw.cgiを使って取得
-
-  (2-2) 旧URLから取得
-
-  (2-3) http://HOGE.2ch.net/hoge/kako/1234/12345/1234567890.dat.gz から取得。302なら(3)へ
-
-  (3) http://HOGE.2ch.net/hoge/kako/1234/12345/1234567890.dat から取得 
-
-
-  ・スレIDが9桁の場合 → http://サーバ/板ID/kako/IDの上位3桁/ID.dat.gz
-
-  (例) http://HOGE.2ch.net/test/read.cgi/hoge/123456789/ を取得
-
-  (1) http://HOGE.2ch.net/hoge/dat/1234567890.dat から dat を取得。302で●がある場合(2-1)、旧URLがある場合(2-2)、無い場合は(2-3)へ(※)
-
-  (2-1) offlaw.cgiを使って取得
-
-  (2-2) 旧URLから取得
-
-  (2-3) http://HOGE.2ch.net/hoge/kako/123/123456789.dat.gz から取得。302なら(3)へ
-
-  (3) http://HOGE.2ch.net/hoge/kako/123/123456789.dat から取得 
-
-
-  (※)ただし 2008年1月1日以降に立てられたスレは除く
-
-  (注) 古すぎる(2000年頃)のdatは形式が違う(<>ではなくて,で区切られている)ので読み込みに失敗する
+        ・スレIDが9桁の場合 -> https://サーバ/板ID/oyster/IDの上位3桁/ID.dat
 
+        (例) https://HOGE.5ch.net/test/read.cgi/hoge/123456789/ を取得
+        (1) https://HOGE.5ch.net/hoge/dat/123456789.dat から DAT を取得。
+        (2) https://HOGE.5ch.net/hoge/oyster/123/123456789.dat から取得。
+        (3) 旧URL(過去ログサーバ)がある場合、そのURLで再取得
 */
 
-        // ログインしている場合は rokka 経由で旧URLで再取得
-        if( m_mode == MODE_NORMAL && CORE::get_login2ch()->login_now() ) m_mode = MODE_OFFLAW;
+        // DAT落ちした現役サーバに収容されているスレッド
+        if( m_mode == MODE_NORMAL ) m_mode = MODE_KAKO;
 
-        // 旧URLがある場合、そのURLで再取得
-        else if( ( m_mode == MODE_NORMAL || m_mode == MODE_OFFLAW ) && get_url() != m_org_url ) m_mode = MODE_OLDURL;
-
-        // 過去ログ倉庫(gz圧縮)
-        // ただし 2008年1月1日以降に立てられたスレは除く
-        else if( ( m_mode == MODE_NORMAL || m_mode == MODE_OFFLAW || m_mode == MODE_OLDURL ) && m_since_time < 1199113200 ) m_mode = MODE_KAKO_GZ;
-
-        // 過去ログ倉庫
-        else if( m_mode == MODE_KAKO_GZ ) m_mode = MODE_KAKO;
+        // 旧URL(過去ログサーバ)に収容されているスレッド
+        else if( m_mode == MODE_KAKO && get_url() != m_org_url ) m_mode = MODE_OLDURL;
 
         // 失敗
         else m_mode = MODE_NORMAL;
@@ -318,7 +241,7 @@ void NodeTree2ch::receive_finish()
         }
     }
 
-    // offlaw や 過去ログから読み込んだ場合は DAT 落ちにする
+    // 過去ログから読み込んだ場合は DAT 落ちにする
     if( m_mode != MODE_NORMAL ){
         m_mode = MODE_NORMAL;
         set_code( HTTP_OLD );
