@@ -12,6 +12,9 @@
 
 #include "config/globalconf.h"
 
+#include <cstring>
+
+
 using namespace DBTREE;
 
 
@@ -66,67 +69,11 @@ void NodeTree2chCompati::init_loading()
     NodeTreeBase::init_loading();
 
     // iconv 初期化
-    std::string charset = DBTREE::board_charset( get_url() );
-    if( ! m_iconv ) m_iconv = std::make_unique<JDLIB::Iconv>( "UTF-8", charset );
+    if( ! m_iconv ) m_iconv = std::make_unique<JDLIB::Iconv>( Encoding::utf8, DBTREE::article_encoding( get_url() ) );
 }
 
 
 
-//
-// キャッシュに保存する前の前処理
-//
-// 先頭にrawモードのステータスが入っていたら取り除く
-//
-char* NodeTree2chCompati::process_raw_lines( char* rawlines )
-{
-    char* pos = rawlines;
-
-    if( *pos == '+' || *pos == '-' || *pos == 'E' ){
-
-        int status = 0;
-        if( pos[ 1 ] == 'O' && pos[ 2 ] == 'K' ) status = 1;
-        if( pos[ 1 ] == 'E' && pos[ 2 ] == 'R' && pos[ 3 ] == 'R' ) status = 2;        
-        if( pos[ 1 ] == 'I' && pos[ 2 ] == 'N' && pos[ 3 ] == 'C' && pos[ 4 ] == 'R' ) status = 3;
-        if( pos[ 0 ] == 'E' && pos[ 1 ] == 'R' && pos[ 2 ] == 'R' && pos[ 3 ] == 'O' && pos[ 4 ] == 'R' ) status = 4;
-
-#ifdef _DEBUG
-        std::cout << "NodeTree2chCompati::process_raw_lines : raw mode status = " << status << std::endl;
-#endif
-
-        if( status != 0 ){
-            pos = skip_status_line( pos, status );
-        }
-    }
-
-    return pos;
-}
-
-
-//
-// ステータス行のスキップ処理
-//   status == 1 : 正常ステータス
-//   status != 1 : 異常ステータス
-// 
-char* NodeTree2chCompati::skip_status_line( char* pos, int status )
-{
-    // この行を飛ばす
-    char* pos_msg = pos;
-    while( *pos != '\n' && *pos != '\0' ) ++pos;
-
-    // エラー
-    if( status != 1 ){
-        int byte;
-        std::string ext_err = std::string( m_iconv->convert( pos_msg, pos - pos_msg, byte ) );
-        set_ext_err( ext_err );
-        MISC::ERRMSG( ext_err );
-    }
-
-    if( *pos == '\n' ) ++pos;
-
-    return pos;
-}
-
-
 //
 // raw データを dat 形式に変換
 //
@@ -137,7 +84,9 @@ const char* NodeTree2chCompati::raw2dat( char* rawlines, int& byte )
     assert( m_iconv != nullptr );
 
     // バッファ自体はiconvクラスの中で持っているのでポインタだけもらう
-    return  m_iconv->convert( rawlines, strlen( rawlines ), byte );
+    const std::string& result = m_iconv->convert( rawlines, std::strlen( rawlines ) );
+    byte = result.size();
+    return result.c_str();
 }
 
 
@@ -153,6 +102,8 @@ void NodeTree2chCompati::create_loaderdata( JDLIB::LOADERDATA& data )
     // 1byte前からレジュームして '\n' が返ってこなかったらあぼーんがあったってこと
     if( get_lng_dat() ) {
         data.byte_readfrom = get_lng_dat() -1;
+        // 更新チェックのときは未取得の範囲を指定する
+        if( is_checking_update() ) data.byte_readfrom += 1;
         set_resume( true );
     }
     else set_resume( false );
