@@ -32,11 +32,8 @@ namespace DBTREE
 
         void clear() override;
         void init_loading() override;
-        char* process_raw_lines( char* rawlines ) override;
         const char* raw2dat( char* rawlines, int& byte ) override;
 
-        char* skip_status_line( char* pos, int status );
-
         void create_loaderdata( JDLIB::LOADERDATA& data ) override;
     };
 }
