@@ -45,6 +45,7 @@ namespace DBTREE
         SIG_UPDATED m_sig_finished;
 
         std::string m_url;
+        std::string m_url_readcgi;
         std::string m_default_noname;
 
         // コード変換前の生データのサイズ ( byte )
@@ -115,6 +116,8 @@ namespace DBTREE
         std::string m_buffer_lines;
         std::string m_parsed_text; // HTMLパーサに使うバッファ
         std::string m_buffer_write; // 書き込みチェック用バッファ
+        std::string m_buf_text; ///< 画面に表示するテキスト用バッファ, parse_html() で使う
+        std::string m_buf_link; ///< 編集したリンク用バッファ, parse_html() で使う
         bool m_check_update{}; // HEADによる更新チェックのみ
         bool m_check_write{}; // 自分の書き込みかチェックする
         bool m_loading_newthread{}; // 新スレ読み込み中
@@ -283,7 +286,7 @@ namespace DBTREE
 
         // 保存前にrawデータを加工
         // デフォルトでは何もしない
-        virtual char* process_raw_lines( char* rawlines ){ return rawlines; }
+        virtual char* process_raw_lines( std::string& rawlines ){ return rawlines.data(); }
 
         // raw データを dat に変換
         // デフォルトでは何もしない
@@ -292,8 +295,9 @@ namespace DBTREE
             return rawlines;
         }
 
-        void receive_data( const char* data, size_t size ) override;
+        void receive_data( std::string_view buf ) override;
         void receive_finish() override;
+        void sweep_buffer();
 
         // 拡張属性を取り出す
         virtual void parse_extattr( std::string_view str ) {};
@@ -306,11 +310,10 @@ namespace DBTREE
         NODE* create_node_idnum();
         NODE* create_node_br();
         NODE* create_node_hr();
-        NODE* create_node_space( const int type );
-        NODE* create_node_multispace( std::string_view text, const char fontid = FONT_MAIN );
-        NODE* create_node_htab();
-        NODE* create_node_link( std::string_view text, std::string_view link,
-                                const int color_text, const bool bold, const char fontid = FONT_MAIN );
+        NODE* create_node_space( const int type, const int bg );
+        NODE* create_node_multispace( std::string_view text, const int bg, const char fontid = FONT_MAIN );
+        NODE* create_node_link( std::string_view text, std::string_view link, const int color_text,
+                                const int color_back, const bool bold, const char fontid = FONT_MAIN );
         NODE* create_node_anc( std::string_view text, std::string_view link,
                                const int color_text, const bool bold,
                                const ANCINFO* ancinfo, const int lng_ancinfo, const char fontid = FONT_MAIN );
@@ -318,12 +321,13 @@ namespace DBTREE
         NODE* create_node_img( std::string_view text, std::string_view link, const int color_text,
                                const bool bold, const char fontid = FONT_MAIN );
         NODE* create_node_text( std::string_view text, const int color_text, const bool bold = false, const char fontid = FONT_MAIN );
-        NODE* create_node_ntext( const char* text, const int n, const int color_text, const bool bold = false, const char fontid = FONT_MAIN );
+        NODE* create_node_ntext( const char* text, const int n, const int color_text, const int color_back = 0,
+                                 const bool bold = false, const char fontid = FONT_MAIN );
         NODE* create_node_thumbnail( std::string_view text, std::string_view link, std::string_view thumb,
                                      const int color_text, const bool bold, const char fontid = FONT_MAIN );
 
         // 以下、構文解析用関数
-        void add_raw_lines( char* rawines, size_t size );
+        void add_raw_lines( std::string& buffer_lines );
         const char* add_one_dat_line( const char* datline );
 
         void parse_name( NODE* header, std::string_view str, const int color_name );
@@ -334,18 +338,17 @@ namespace DBTREE
         // digitlink : true の時は先頭に数字が現れたらアンカーにする( parse_name() などで使う )
         //             false なら数字の前に >> がついてるときだけアンカーにする
         // bold : ボールド表示
-        // ahref : <a href=～></a> からリンクノードを作成する
-        void parse_html( std::string_view str, const int color_text,
-                         bool digitlink, const bool bold, const bool ahref, const char fontid = FONT_MAIN );
+        void parse_html( const char* str, std::size_t lng_str, const int color_text,
+                         bool digitlink, const bool bold, const char fontid = FONT_MAIN );
 
         // 書き込みログ比較用文字列作成
         // m_buffer_write に作成した文字列をセットする
         void parse_write( std::string_view str, const std::size_t max_lng_write );
 
-        bool check_anchor( const int mode, const char* str_in, int& n, char* str_out, char* str_link, int lng_link,
+        bool check_anchor( const int mode, const char* str_in, int& n, std::string& str_out, std::string& str_link,
                            ANCINFO* ancinfo ) const;
         /// リンクが現れたかチェックして文字列を取得する関数
-        int check_link( const char* str_in, const int lng_in, int& n_in, char* str_link, const int lng_link ) const;
+        int check_link( const char* str_in, int& lng_in, std::string& str_text, std::string& str_link ) const;
 
         // レジューム時のチェックデータをキャッシュ
         void set_resume_data( const char* data, size_t length );
@@ -403,10 +406,7 @@ namespace DBTREE
 
       public:
         // http://ime.nu/ などをリンクから削除
-        static bool remove_imenu( char* str_link );
-
-        // 文字列中の"&amp;"を"&"に変換する
-        static int convert_amp( char* text, const int n );
+        static bool remove_imenu( std::string& str_link );
     };
 }
 
