@@ -9,8 +9,10 @@
 
 #include "nodetreebase.h"
 
+#include <memory>
 #include <string>
 
+
 namespace JDLIB
 {
     class Iconv;
@@ -21,7 +23,7 @@ namespace DBTREE
 {
     class NodeTreeJBBS : public NodeTreeBase
     {
-        JDLIB::Iconv* m_iconv;
+        std::unique_ptr<JDLIB::Iconv> m_iconv;
         std::string m_decoded_lines;
 
       public:
