@@ -9,8 +9,8 @@
 #include "jdlib/jdiconv.h"
 #include "jdlib/jdregex.h"
 #include "jdlib/loaderdata.h"
+#include "jdlib/misccharcode.h"
 #include "jdlib/miscutil.h"
-#include "jdlib/miscmsg.h"
 
 #include "config/globalconf.h"
 
@@ -85,8 +85,7 @@ void NodeTreeMachi::init_loading()
     if( ! m_regex ) m_regex = std::make_unique<JDLIB::Regex>();
 
     // iconv 初期化
-    std::string charset = DBTREE::board_charset( get_url() );
-    if( ! m_iconv ) m_iconv = std::make_unique<JDLIB::Iconv>( "UTF-8", charset );
+    if( ! m_iconv ) m_iconv = std::make_unique<JDLIB::Iconv>( Encoding::utf8, DBTREE::article_encoding( get_url() ) );
 
     m_buffer_for_200.clear();
 
@@ -148,10 +147,10 @@ void NodeTreeMachi::create_loaderdata( JDLIB::LOADERDATA& data )
 //
 // キャッシュに保存する前の前処理
 //
-char* NodeTreeMachi::process_raw_lines( char* rawlines )
+char* NodeTreeMachi::process_raw_lines( std::string& rawlines )
 {
     // オフラインか offlaw 形式を使用する場合はそのまま返す
-    if( ! is_loading() || CONFIG::get_use_machi_offlaw() ) return rawlines;
+    if( ! is_loading() || CONFIG::get_use_machi_offlaw() ) return rawlines.data();
 
     const size_t offset = 0;
     const bool icase = false;
@@ -192,10 +191,9 @@ char* NodeTreeMachi::process_raw_lines( char* rawlines )
                 std::string reg_subject( "<title>([^<]*)</title>" );
                 if( m_regex->exec( reg_subject, line, offset, icase, newline, usemigemo, wchar ) ){
 
-                    const std::string charset = DBTREE::board_charset( get_url() );
-                    m_subject_machi = MISC::Iconv( m_regex->str( 1 ), "UTF-8", charset );
+                    m_subject_machi = MISC::Iconv( m_regex->str( 1 ), Encoding::utf8, get_encoding() );
 #ifdef _DEBUG
-                    std::cout << "NodeTreeMachi::process_raw_lines\n";
+                    std::cout << "NodeTreeMachi::process_raw_lines" << std::endl;
                     std::cout << "subject = " << m_subject_machi << std::endl;
 #endif
                 }
@@ -215,11 +213,6 @@ char* NodeTreeMachi::process_raw_lines( char* rawlines )
         }
     }
 
-    if( buffer.length() > BUF_SIZE_ICONV_OUT ){
-        MISC::ERRMSG( "buffer over flow in NodeTreeMachi::process_raw_lines" );
-        buffer = std::string();
-    }
-
     m_buffer = std::move( buffer );
 
     return &*m_buffer.begin();
@@ -246,8 +239,7 @@ const char* NodeTreeMachi::raw2dat( char* rawlines, int& byte )
     std::string buffer;
 
     // 文字コード変換
-    int byte_lines;
-    const char* str_lines = m_iconv->convert( rawlines, strlen( rawlines ), byte_lines );
+    const std::string& str_lines = m_iconv->convert( rawlines, std::strlen( rawlines ) );
 
     std::list< std::string > lines = MISC::get_lines( str_lines );
     for( std::string& line : lines ) {
@@ -285,22 +277,25 @@ const char* NodeTreeMachi::raw2dat( char* rawlines, int& byte )
         // read.cgi 形式
         else{
 
-            std::string reg( "<dt>([1-9][0-9]*) ?名前：(<a href=\"mailto:([^\"]*)\"><b>|<font[^>]*><b>) ?(<font[^>]*>)?([^<]*)(</font>)? ?</[bB]>.+ ?投稿日： ?([^<]*)( <font[^>]*>\\[ ?(.*) ?\\]</font>)?<br><dd> ?(.*) ?<br><br>$" );
+            constexpr const char* reg =
+                "<dt>([1-9][0-9]*) ?名前：(?:<a href=\"mailto:([^\"]*)\"><b>|<font[^>]*><b>) ?"
+                "(?:<font[^>]*>)?([^<]*)(?:</font>)? ?</[bB]>.+ ?投稿日： ?([^>]*)"
+                "(?: <font[^>]*>\\[ ?([!-~]*) ?\\]</font>)?<br><dd> ?(.*) ?<br><br>(<script[^>]*>)?$";
 
             if( ! m_regex->exec( reg, line, offset, icase, newline, usemigemo, wchar ) ){
 #ifdef _DEBUG
-                std::cout << "失敗\n";
+                std::cout << "NodeTreeMachi::raw2dat read.cgi regex 失敗\n";
                 std::cout << line << std::endl;
 #endif
                 continue;
             }
 
-            num = atoi( m_regex->str( 1 ).c_str() );
-            name = m_regex->str( 5 );
-            mail = m_regex->str( 3 );
-            date = m_regex->str( 7 );
-            if( !m_regex->str( 9 ).empty() ) date += " HOST:" + m_regex->str( 9 );
-            body = m_regex->str( 10 );
+            num = std::atoi( m_regex->str( 1 ).c_str() );
+            name = m_regex->str( 3 );
+            mail = m_regex->str( 2 );
+            date = m_regex->str( 4 );
+            if( std::string id = m_regex->str( 5 ); ! id.empty() ) date += " HOST:" + id;
+            body = m_regex->str( 6 );
         }
 
         while( next < num ){
@@ -322,11 +317,6 @@ const char* NodeTreeMachi::raw2dat( char* rawlines, int& byte )
         ++next;
     }
 
-    if( buffer.length() > BUF_SIZE_ICONV_OUT ){
-        MISC::ERRMSG( "buffer over flow in NodeTreeMachi::process_raw_lines" );
-        buffer = std::string();
-    }
-
     m_decoded_lines = std::move( buffer );
     byte = m_decoded_lines.size();
 
@@ -338,7 +328,7 @@ const char* NodeTreeMachi::raw2dat( char* rawlines, int& byte )
 //
 // ローダからデータ受け取り
 //
-void NodeTreeMachi::receive_data( const char* data, size_t size )
+void NodeTreeMachi::receive_data( std::string_view buf )
 {
     // dat落ち判定用処理。 receive_finish() も参照
     if( ! is_checking_update() && get_code() == HTTP_OK && m_buffer_for_200.empty() ) {
@@ -346,11 +336,10 @@ void NodeTreeMachi::receive_data( const char* data, size_t size )
         std::cout << "NodeTreeMachi::receive_data : save some bytes\n";
 #endif
 
-        const int lng = MIN( size, BUF_SIZE_200 );
-        m_buffer_for_200.append( data, lng );
+        m_buffer_for_200.append( buf.substr( 0, BUF_SIZE_200 ) );
     }
 
-    NodeTreeBase::receive_data( data, size );
+    NodeTreeBase::receive_data( buf );
 }
 
 
@@ -368,8 +357,7 @@ void NodeTreeMachi::receive_finish()
     if( m_buffer_for_200.size() >= 2 && m_buffer_for_200[ 0 ] == '<'
             && ( m_buffer_for_200[ 1 ] == 'E' || m_buffer_for_200[ 1 ] == 'h' ) ) {
 
-        int byte_lines;
-        std::string str_lines( m_iconv->convert( &*m_buffer_for_200.begin(), m_buffer_for_200.size(), byte_lines ) );
+        const std::string& str_lines = m_iconv->convert( m_buffer_for_200.data(), m_buffer_for_200.size() );
 
 #ifdef _DEBUG    
         std::cout << str_lines << std::endl;
