@@ -10,6 +10,7 @@
 #include "nodetreebase.h"
 
 #include <memory>
+#include <string_view>
 
 
 namespace JDLIB
@@ -43,10 +44,10 @@ namespace DBTREE
         void clear() override;
         void init_loading() override;
         void create_loaderdata( JDLIB::LOADERDATA& data ) override;
-        char* process_raw_lines( char* rawlines ) override;
+        char* process_raw_lines( std::string& rawlines ) override;
         const char* raw2dat( char* rawlines, int& byte ) override;
 
-        void receive_data( const char* data, size_t size ) override;
+        void receive_data( std::string_view buf ) override;
         void receive_finish() override;
     };
 }
