@@ -17,10 +17,9 @@
 
 using namespace DBTREE;
 
-RuleLoader::RuleLoader( const std::string& url_boadbase, const char* override_charset )
+RuleLoader::RuleLoader( const std::string& url_boadbase )
     : SKELETON::TextLoader()
     , m_url_boadbase( url_boadbase )
-    , m_override_charset{ override_charset }
 {
 #ifdef _DEBUG
     std::cout << "RuleLoader::RuleLoader : " << RuleLoader::get_url() << std::endl;
@@ -50,12 +49,6 @@ std::string RuleLoader::get_path() const
 }
 
 
-std::string RuleLoader::get_charset() const
-{
-    return m_override_charset ? m_override_charset : DBTREE::board_charset( m_url_boadbase );
-}
-
-
 // ロード用データ作成
 void RuleLoader::create_loaderdata( JDLIB::LOADERDATA& data )
 {
