@@ -6,7 +6,7 @@
 #ifndef _IOMONITOR_H
 #define _IOMONITOR_H
 
-#include <gtkmm.h>
+#include <glibmm.h>
 
 
 namespace CORE
@@ -36,9 +36,6 @@ namespace CORE
 
       private:
 
-        // 初期化
-        void init();
-
         // FIFOを削除する
         void delete_fifo();
 
@@ -50,6 +47,9 @@ namespace CORE
         IOMonitor();
         ~IOMonitor();
 
+        /// FIFOの初期化
+        void init_connection();
+
         // FIFOの状態を取得
         int get_fifo_stat() const noexcept { return m_fifo_stat; }
 
@@ -57,7 +57,7 @@ namespace CORE
         bool is_main_process() const noexcept { return m_main_process; }
 
         // FIFOに書き込み
-        bool send_command( const char* command );
+        bool send_command( const std::string& command );
     };
 }
 #endif
