@@ -30,12 +30,12 @@ namespace JDLIB
         
         std::string m_file;
         std::string m_errmsg;
-        int m_width;
-        int m_height;
-        
-        bool m_stop;
-        int m_y;
-        int m_loadlevel;
+        int m_width{};
+        int m_height{};
+
+        bool m_stop{};
+        int m_y{};
+        int m_loadlevel{};
         int m_loadedlevel;
         
     public:
@@ -54,7 +54,7 @@ namespace JDLIB
         bool equals( const std::string& file ) const;
         
     private:
-        ImgLoader( const std::string& file );
+        explicit ImgLoader( const std::string& file );
         bool load_imgfile( const int loadlevel );
         
         void slot_size_prepared( int w, int h );
