@@ -5,12 +5,104 @@
 
 #include "misccharcode.h"
 
+#include "jdiconv.h"
+
+#include <glib.h>
+
+#include <cstdint>
 #include <cstring>
+#include <iterator>
 
 
 // チェックする最大バイト数
 #define CHECK_LIMIT 1024
 
+
+namespace MISC::charset {
+constexpr const char* iconv[] = { "ISO-8859-1", "ASCII", "EUCJP-MS", "ISO-2022-JP", "MS932", "UTF-8" };
+constexpr const char* names[] = { "ISO-8859-1", "ASCII", "EUC-JP", "ISO-2022-JP", "Shift_JIS", "UTF-8" };
+static_assert( std::size( iconv ) == std::size( names ) );
+
+template<typename T>
+const char* encoding_to_impl( Encoding enc, T&& strings )
+{
+    if( enc > Encoding::utf8 || enc < Encoding::unknown ) enc = Encoding::unknown;
+    return strings[ static_cast<int>( enc ) ];
+}
+} // namespace MISC::charset
+
+
+/** @brief `Encoding` からUIに表示したり情報ファイルに保存するのに使う文字エンコーディング名を取得する
+ *
+ * @param[in] encoding 文字エンコーディング
+ * @return encodingに対応するヌル終端文字列。
+ * `Encoding::unknown` のとき、または不正な値なら `"ISO-8859-1"` (Latin1) を返す。
+ */
+const char* MISC::encoding_to_cstr( const Encoding encoding )
+{
+    return charset::encoding_to_impl( encoding, charset::names );
+}
+
+
+/** @brief `Encoding` から JDLIB::Iconv クラスに渡す文字エンコーディング名を取得する
+ *
+ * @param[in] encoding 文字エンコーディング
+ * @return encodingに対応するヌル終端文字列。
+ * `Encoding::unknown` のとき、または不正な値なら `"ISO-8859-1"` (Latin1) を返す。
+ */
+const char* MISC::encoding_to_iconv_cstr( const Encoding encoding )
+{
+    return charset::encoding_to_impl( encoding, charset::iconv );
+}
+
+
+/** @brief 文字エンコーディングを表す文字列から`Encoding`を取得する
+ *
+ * @param[in] encoding 文字エンコーディング名 (not null)
+ * @return 文字列に対応する列挙型。見つからなければ `Encoding::unknown` を返す。
+ */
+Encoding MISC::encoding_from_sv( std::string_view encoding )
+{
+    assert( encoding.data() );
+
+    for( std::size_t i = std::size( charset::names ) - 1; i > 0; --i ){
+        if( encoding == charset::names[i] ) return static_cast<Encoding>( i );
+    }
+    // 互換性のため JDLIB::Iconv クラスで使うエンコーディング名と一致するかチェックする
+    if( encoding == charset::iconv[ static_cast<int>( Encoding::sjis ) ] ) return Encoding::sjis;
+    if( encoding == charset::iconv[ static_cast<int>( Encoding::eucjp ) ] ) return Encoding::eucjp;
+    return Encoding::unknown;
+}
+
+
+/** @brief Webで使われる文字エンコーディングのラベルから`Encoding`を取得する
+ *
+ * @details 入力文字列から繋ぎの記号(`-`, `_`)を取り除き大文字小文字を無視して比較する。
+ * @param[in] charset 文字エンコーディングのラベル
+ * @return 文字列に対応する列挙型。見つからなければ `Encoding::unknown` を返す。
+ */
+Encoding MISC::encoding_from_web_charset( std::string_view charset )
+{
+    std::string casefold;
+    casefold.reserve( charset.size() );
+
+    for( const char c : charset ) {
+        if( c == '_' || c == '-' ) continue;
+        casefold.push_back( g_ascii_toupper( c ) );
+    }
+
+    if( casefold == "UTF8" ) return Encoding::utf8;
+    if( casefold == "SHIFTJIS"
+        || casefold == "SJIS"
+        || casefold == "XSJIS"
+        || casefold == "WINDOWS31J" ) return Encoding::sjis;
+    if( casefold == "EUCJP"
+        || casefold == "XEUCJP" ) return Encoding::eucjp;
+    // その他は使わないため unknown を返す
+    return Encoding::unknown;
+}
+
+
 /*--- 制御文字とASCII -----------------------------------------------*/
 
 // [ 制御文字 ] 0x00〜0x1F 0x7F
@@ -100,7 +192,7 @@ bool MISC::is_eucjp( std::string_view input, std::size_t read_byte )
 //
 /** @brief 文字列のエンコーディングがISO-2022-JPか簡易判定する
  *
- * エスケープシーケンス(ESC = \x1B)の有無と該当しないバイトが含まれるかチェックする。
+ * エスケープシーケンス(ESC = \\x1B)の有無と該当しないバイトが含まれるかチェックする。
  * 呼び出し元の処理のため空文字列に対する返り値は他の`is_*`関数と逆(false)になっている。
  * @param[in] input 入力
  * @param[in,out] byte チェックを開始する位置、チェックを打ち切った位置を返す
@@ -269,31 +361,32 @@ bool MISC::is_utf8( std::string_view input, std::size_t read_byte )
 }
 
 
-//
-// 日本語文字コードの判定
-//
-// 各コードの判定でtrueの間は文字数分繰り返されるので
-// 速度の求められる繰り返し処理などで使わない事
-//
-int MISC::judge_char_code( const std::string& str )
+/** @brief 日本語文字エンコーディングの検出
+ *
+ * @note 各エンコーディングの判定でtrueの間は文字数分繰り返されるので
+ * 速度の求められる繰り返し処理などで使わない事
+ * @param[in] str エンコーディングを検出するテキスト
+ * @return 検出結果
+ */
+Encoding MISC::detect_encoding( std::string_view str )
 {
-    int code = CHARCODE_UNKNOWN;
+    Encoding code = Encoding::unknown;
 
     if( str.empty() ) return code;
 
     size_t read_byte = 0;
 
     // JISの判定
-    if( is_jis( str, read_byte ) ) code = CHARCODE_JIS;
+    if( is_jis( str, read_byte ) ) code = Encoding::jis;
     // JISの判定で最後まで進んでいたら制御文字かアスキー
-    else if( read_byte == str.length() ) code = CHARCODE_ASCII;
+    else if( read_byte == str.length() ) code = Encoding::ascii;
     // is_jis()でASCII範囲外のバイトが現れた箇所から判定する
     // UTF-8の範囲
-    else if( is_utf8( str, read_byte ) ) code = CHARCODE_UTF;
+    else if( is_utf8( str, read_byte ) ) code = Encoding::utf8;
     // EUC-JPの範囲
-    else if( is_eucjp( str, read_byte ) ) code = CHARCODE_EUC_JP;
+    else if( is_eucjp( str, read_byte ) ) code = Encoding::eucjp;
     // Shift_JISの範囲
-    else if( is_sjis( str, read_byte ) ) code = CHARCODE_SJIS;
+    else if( is_sjis( str, read_byte ) ) code = Encoding::sjis;
 
     return code;
 }
@@ -498,3 +591,23 @@ std::string MISC::utf8_fix_wavedash( const std::string& str, const MISC::WaveDas
 
     return result;
 }
+
+
+/** @brief 入力の文字エンコーディングを from から to に変換
+ *
+ * @details 遅いので連続的な処理が必要な時は使わないこと
+ * @param[in] str  変換するテキスト
+ * @param[in] to   変換先の文字エンコーディング
+ * @param[in] from str の文字エンコーディング
+ * @return 変換した結果
+ */
+std::string MISC::Iconv( const std::string& str, const Encoding to, const Encoding from )
+{
+    if( from == to ) return str;
+
+    JDLIB::Iconv icv( to, from );
+    std::string tmp_str{ str };
+    std::string encoded;
+    icv.convert( tmp_str.data(), tmp_str.size(), encoded );
+    return encoded;
+}
