@@ -3,12 +3,13 @@
 //#define _DEBUG
 #include "jddebug.h"
 
+#include "miscutil.h"
+
 #include "hkana.h"
 #include "jdiconv.h"
 #include "jdregex.h"
 #include "misccharcode.h"
 #include "miscmsg.h"
-#include "miscutil.h"
 
 #include "dbtree/spchar_decoder.h"
 #include "dbtree/node.h"
@@ -17,10 +18,11 @@
 
 #include <glib.h>
 
-#include <sstream>
-#include <cstring>
 #include <cstdio>
 #include <cstdlib>
+#include <cstring>
+#include <memory>
+#include <sstream>
 
 
 //
@@ -310,34 +312,31 @@ std::string MISC::concat_with_suffix( const std::list<std::string>& list_in, cha
  * @param[in] str トリミングする文字列
  * @return トリミングした結果
  */
-std::string MISC::utf8_trim( const std::string& str )
+std::string MISC::utf8_trim( std::string_view str )
 {
-    constexpr const char* str_space = u8"\u3000"; // "\xE3\x80\x80" 全角スペース
-    constexpr size_t lng_space = 3;
+    constexpr std::string_view str_space = "\xE3\x80\x80"; // U+3000 全角スペース
+    constexpr std::size_t lng_space = str_space.size();
 
-    size_t lng = str.length();
-    
-    if( lng == 0 ) return str;
+    if( str.empty() ) return std::string{};
     // TODO: 半角スペースがなくてもトリミングしたほうがよいか検証する
-    if( str.find( ' ' ) == std::string::npos ) return str;
+    if( str.find( ' ' ) == std::string_view::npos ) return std::string{ str };
 
     // 前
-    size_t i = 0;
-    while( i < lng ){
+    std::size_t i = 0;
+    while( i < str.size() ) {
 
         // 半角
         if( str[ i ] == ' ' ) ++i;
 
         // 全角
-        else if( str[ i ] == str_space[ 0 ] &&
-                 str[ i +1 ] == str_space[ 1 ] &&
-                 str[ i +2 ] == str_space[ 2 ] ) i += lng_space;
+        else if( str.compare( i, lng_space, str_space ) == 0 ) i += lng_space;
+
         else break;
     }
-    if (i >= lng) return "";
+    if( i >= str.size() ) return std::string{};
 
     // 後
-    size_t i2 = lng -1;
+    std::size_t i2 = str.size() -1;
     while( 1 ){
 
         // 半角
@@ -345,17 +344,16 @@ std::string MISC::utf8_trim( const std::string& str )
 
         // 全角
         else if( i2 +1 >= lng_space &&
-                 str[ i2 - lng_space +1 ] == str_space[ 0 ] &&
-                 str[ i2 - lng_space +2 ] == str_space[ 1 ] &&
-                 str[ i2 - lng_space +3 ] == str_space[ 2 ] ) i2 -= lng_space;
+                str.compare( i2 - lng_space + 1, lng_space, str_space ) == 0 ) i2 -= lng_space;
+
         else break;
     }
 
-    return str.substr( i, i2 - i + 1 );
+    return std::string{ str.begin() + i, str.begin() + i2 + 1 };
 }
 
 
-/** @brief str前後の改行(\r, \\n)、タブ(\t)、スペース(U+0020)を削除
+/** @brief str前後の改行(\\r, \\n)、タブ(\\t)、スペース(U+0020)を削除
  *
  * @param[in] str トリミングする文字列
  * @return トリミングした結果
@@ -536,7 +534,7 @@ std::list<std::string> MISC::replace_str_list( const std::list<std::string>& lis
 
 /** @brief str に含まれる改行文字(`\r\n`)を replace に置き換え
  *
- * @param[in] str_in 処理する文字列
+ * @param[in] str 処理する文字列
  * @param[in] replace マッチした改行文字と置き換える内容
  * @return 置き換えを実行した結果。str や replace が空文字列のときは str をそのまま返す。
  */
@@ -995,7 +993,7 @@ static std::string chref_decode_one( const char* str, int& n_in, const char pre_
     out_char.resize( n_out );
 
     // 改行、タブ、スペースの処理
-    if( type != DBTREE::NODE_NONE && ( out_char[0] == ' ' || out_char[0] == '\n' ) && pre_char != ' ' ) {
+    if( type == DBTREE::NODE_SP && pre_char != ' ' ) {
         out_char.assign( 1u, ' ' );
     }
     // 変換できない文字
@@ -1070,7 +1068,7 @@ std::string MISC::to_plain( const std::string& html )
 
 /** @brief HTMLをPango markupテキストに変換する
  *
- * @details <mark>と<span>タグの色を設定して文字参照をデコードして返す。
+ * @details `<mark>`と`<span>`タグの色を設定して文字参照をデコードして返す。
  * @param[in] html Pango markupテキストに変換する入力
  * @return 変換した結果
  */
@@ -1108,10 +1106,10 @@ std::string MISC::to_markup( const std::string& html )
                 markuptxt += "<span";
 
                 if( classname.size() ) {
-                    CORE::Css_Manager* mgr = CORE::get_css_manager();
+                    const CORE::Css_Manager* const mgr = CORE::get_css_manager();
                     const int classid = mgr->get_classid( classname );
                     if( classid != -1 ) {
-                        CORE::CSS_PROPERTY css = mgr->get_property( classid );
+                        const CORE::CSS_PROPERTY& css = mgr->get_property( classid );
                         if( css.color != -1 ) markuptxt += " color=\"" + mgr->get_color( css.color ) + "\"";
                         if( css.bg_color != -1 ) markuptxt += " background=\"" + mgr->get_color( css.bg_color ) + "\"";
                     }
@@ -1350,82 +1348,108 @@ std::string MISC::url_decode( std::string_view url )
 }
 
 
-//
-// url エンコード
-//
-std::string MISC::url_encode( const char* str, const size_t n )
+/** @brief 文字列(バイト列)をパーセント符号化して返す
+ *
+ * @details URL Living Standard が定めるpercent-encode setを参考にバイトを符号化する。
+ * - 半角英数字(0-9 A-Z a-z)と一部記号(* - . _)は変換しない
+ * - それ以外はパーセント記号ではじまる16進表記 \%XX に変換 (A-Fは大文字)
+ *
+ * @param[in] str 入力文字列 (文字エンコーディングは任意)
+ * @return パーセント符号化された文字列
+ * @see MISC::url_encode( const std::string& utf8str, const Encoding encoding )
+*/
+std::string MISC::url_encode( std::string_view str )
 {
-    if( str[ n ] != '\0' ){
-        ERRMSG( "url_encode : invalid input." );
-        return std::string();
-    }
-
     std::string str_encoded;
-    
-    for( size_t i = 0; i < n; i++ ){
-        
-        unsigned char c = str[ i ];
-        const int tmplng = 16;
-        char str_tmp[ tmplng ];
-        
-        if( ! ( 'a' <= c && c <= 'z' ) &&
-            ! ( 'A' <= c && c <= 'Z' ) &&
-            ! ( '0' <= c && c <= '9' ) &&            
-            ( c != '*' ) &&
-            ( c != '-' ) &&
-            ( c != '.' ) &&
-            ( c != '@' ) &&
-            ( c != '_' )){
+    constexpr std::size_t tmplng = 8;
+    char str_tmp[tmplng];
 
-            std::snprintf( str_tmp, tmplng, "%%%02X", c );
+    for( const char c : str ) {
+        if( g_ascii_isalnum( c )  || c == '*' || c == '-' || c == '.' || c == '_' ) {
+            str_encoded.push_back( c );
         }
         else {
-            str_tmp[ 0 ] = c;
-            str_tmp[ 1 ] = '\0';
+            std::snprintf( str_tmp, tmplng, "%%%02X", static_cast<unsigned char>( c ) );
+            str_encoded.append( str_tmp );
         }
-
-        str_encoded += str_tmp;
     }
 
     return str_encoded;
 }
 
 
-std::string MISC::url_encode( const std::string& str )
+/** @brief UTF-8文字列をエンコーディング変換してからパーセント符号化して返す
+ *
+ * @details `utf8str` を `encoding` で指定した文字エンコーディングに変換してから符号化する。
+ * @param[in] utf8str 入力文字列 (文字エンコーディングはUTF-8)
+ * @param[in] encoding 変換先の文字エンコーディング
+ * @return パーセント符号化された文字列
+ * @see MISC::url_encode( std::string_view str )
+*/
+std::string MISC::url_encode( const std::string& utf8str, const Encoding encoding )
 {
-    return url_encode( str.c_str(), str.length() );
+    if( encoding == Encoding::utf8 ) return MISC::url_encode( utf8str );
+
+    const std::string str_enc = MISC::Iconv( utf8str, encoding, Encoding::utf8 );
+    return MISC::url_encode( str_enc );
 }
 
 
-//
-// 文字コード変換して url エンコード
-//
-// str は UTF-8 であること
-//
-std::string MISC::charset_url_encode( const std::string& str, const std::string& charset )
+/** @brief application/x-www-form-urlencoded の形式でパーセント符号化する
+ *
+ * webブラウザのform要素の挙動に合わせてURLの規格と異なる変換処理がある。
+ * - 半角英数字(0-9 A-Z a-z)と一部記号(* - . _)は変換しない
+ * - 改行LF(U+000A) は \%0D\%0A に変換する
+ * - 改行CR(U+000D) は読み飛ばして無視する
+ * - 半角空白(U+0020)は + プラス記号(U+002B)に置換する
+ * - それ以外はパーセント記号ではじまる16進表記 \%XX に変換 (A-Fは大文字)
+ *
+ * @param[in] str 入力文字列 (文字エンコーディングは任意)
+ * @return パーセント符号化された文字列
+ * @see MISC::url_encode_plus( const std::string& utf8str, const Encoding encoding )
+*/
+std::string MISC::url_encode_plus( std::string_view str )
 {
-    if( charset.empty() || charset == "UTF-8" ) return MISC::url_encode( str.c_str(), str.length() );
+    std::string str_encoded;
+    constexpr std::size_t tmplng = 8;
+    char str_tmp[tmplng];
 
-    const std::string str_enc = MISC::Iconv( str, charset, "UTF-8" );
-    return  MISC::url_encode( str_enc.c_str(), str_enc.length() );
-}
-
-
-//
-// 文字コード変換して url エンコード
-//
-// ただし半角スペースのところを+に置き換えて区切る
-//
-std::string MISC::charset_url_encode_split( const std::string& str, const std::string& charset )
-{
-    std::list< std::string > list_str = MISC::split_line( str );
-    std::string str_out;
-    for( const std::string& s : list_str ) {
-        if( ! str_out.empty() ) str_out.push_back( '+' );
-        str_out.append( MISC::charset_url_encode( s, charset ) );
+    for( const char c : str ) {
+        if( g_ascii_isalnum( c ) || c == '-' || c == '.' || c == '_' || c == '*' ) {
+            str_encoded.push_back( c );
+        }
+        else if( c == ' ' ) {
+            str_encoded.push_back( '+' );
+        }
+        else if( c == '\n' ) {
+            str_encoded.append( "%0D%0A" );
+        }
+        else if( c != '\r' ) {
+            std::snprintf( str_tmp, tmplng, "%%%02X", static_cast<unsigned char>( c ) );
+            str_encoded.append( str_tmp );
+        }
     }
 
-    return str_out;
+    return str_encoded;
+}
+
+
+/** @brief UTF-8文字列をエンコーディング変換してから application/x-www-form-urlencoded の形式でパーセント符号化する
+ *
+ * @details `utf8str` を `encoding` で指定した文字エンコーディングに変換してから符号化する。
+ * @param[in] utf8str 入力文字列 (文字エンコーディングはUTF-8)
+ * @param[in] encoding 変換先の文字エンコーディング名
+ * @return パーセント符号化された文字列
+ * @see MISC::url_encode_plus( std::string_view str )
+*/
+std::string MISC::url_encode_plus( const std::string& utf8str, const Encoding encoding )
+{
+    if( encoding == Encoding::utf8 ) {
+        return MISC::url_encode_plus( utf8str );
+    }
+
+    const std::string str_enc = MISC::Iconv( utf8str, encoding, Encoding::utf8 );
+    return MISC::url_encode_plus( str_enc );
 }
 
 
@@ -1476,27 +1500,6 @@ std::string MISC::base64( const std::string& str )
 
 
 
-
-//
-// 文字コードを coding_from から coding_to に変換
-//
-// 遅いので連続的な処理が必要な時は使わないこと
-//
-std::string MISC::Iconv( const std::string& str, const std::string& coding_to, const std::string& coding_from )
-{
-    if( coding_from == coding_to ) return str;
-
-    std::string str_bk = str;
-
-    JDLIB::Iconv libiconv( coding_to, coding_from );
-    int byte_out;
-
-    std::string str_enc = libiconv.convert( &*str_bk.begin(), str_bk.size(), byte_out );
-
-    return str_enc;
-}
-
-
 //
 // 「&#数字;」形式の数字参照文字列の中の「数字」部分の文字列長
 //
@@ -1590,14 +1593,14 @@ static char32_t transform_7f_9f( char32_t raw_point )
 }
 
 
-/** @brief 「&#数字;」形式の数値文字参照をコードポイント(char32_t)に変換する
+/** @brief 「`&#数字;`」形式の数値文字参照をコードポイント(char32_t)に変換する
  *
  * @details 数値文字参照の解析エラーとなる値もそのまま返す
  * (Unicodeの範囲外、サロゲート、非文字など)
  * @param[in] in_char 入力文字列、 `in_char[0] == "&" && in_char[1] == "#"` であること (not null)
  * @param[in] offset  spchar_number_ln() の戻り値
  * @param[in] lng     spchar_number_ln() の戻り値
- * @return 「&#数字;」の中の数字(char32_t型)
+ * @return 「`&#数字;`」の中の数字(char32_t型)
  * @remarks 最初に MISC::spchar_number_ln() を呼び出して `offset` と `lng` を取得すること
  */
 char32_t MISC::decode_spchar_number_raw( const char* in_char, const int offset, const int lng )
@@ -1617,13 +1620,13 @@ char32_t MISC::decode_spchar_number_raw( const char* in_char, const int offset,
 }
 
 
-/** @brief 「&#数字;」形式の数値文字参照をコードポイント(char32_t)に変換する
+/** @brief 「`&#数字;`」形式の数値文字参照をコードポイント(char32_t)に変換する
  *
  * @details 数値文字参照の解析エラーとなる値は規定の値に変換して返す
  * @param[in] in_char 入力文字列、 `in_char[0] == "&" && in_char[1] == "#"` であること (not null)
  * @param[in] offset  spchar_number_ln() の戻り値
  * @param[in] lng     spchar_number_ln() の戻り値
- * @return 「&#数字;」の中の数字(char32_t型)
+ * @return 「`&#数字;`」の中の数字(char32_t型)
  * @remarks 最初に MISC::spchar_number_ln() を呼び出して `offset` と `lng` を取得すること
  */
 char32_t MISC::decode_spchar_number( const char* in_char, const int offset, const int lng )
@@ -2143,6 +2146,30 @@ std::string MISC::parse_html_form_action( const std::string& html )
 }
 
 
+/** @brief HTMLのmeta要素からテキストのエンコーディング(charset)を取得する
+ *
+ * @param[in] html HTMLの文字列
+ * @return 文字エンコーディングを表す文字列、見つからないときは空文字列を返す
+ */
+std::string MISC::parse_charset_from_html_meta( const std::string& html )
+{
+    constexpr const char* pattern = R"(<meta\s+(?:http-equiv=["']content-type["']\s+content=["'][^"']*)"
+                                    R"(charset=\s*([^"'\s]+)|charset=["']?\s*([^"'>\s]+)))";
+    JDLIB::Regex regex;
+    constexpr std::size_t offset = 0;
+    constexpr bool icase = true;   // 大文字小文字区別しない
+    constexpr bool newline = true; // . に改行をマッチさせる
+    constexpr bool usemigemo = false;
+    constexpr bool wchar = false;
+
+    if( regex.exec( pattern, html, offset, icase, newline, usemigemo, wchar ) ) {
+        if( regex.length( 1 ) > 0 ) return regex.str( 1 );
+        if( regex.length( 2 ) > 0 ) return regex.str( 2 );
+    }
+    return {};
+}
+
+
 /** @brief haystack の pos 以降から最初に needle と一致する位置を返す (ASCIIだけignore case)
  *
  * @param[in] haystack 検索する文字列
