@@ -18,10 +18,13 @@
 
 #include <cstring>
 
-enum
-{
-    SIZE_OF_RAWDATA = 64 * 1024
-};
+
+#if 0 // サイトの更新に対応していないためサポートを中止
+namespace CORE::ch {
+constexpr std::size_t kSizeOfRawData = 64 * 1024;
+}
+#endif
+
 
 CORE::Login2ch* instance_login2ch = nullptr;
 
@@ -85,6 +88,8 @@ void Login2ch::start_login()
 
     set_str_code( "" );
 
+    finish();
+#if 0 // サイトの更新に対応していないためサポートを中止
     if( ! SESSION::is_online() ){
 
         // ディスパッチャ経由でreceive_finish()を呼ぶ
@@ -109,23 +114,24 @@ void Login2ch::start_login()
     data.str_post += get_passwd();
 
     logout();
-    if( m_rawdata.capacity() < SIZE_OF_RAWDATA ) m_rawdata.reserve( SIZE_OF_RAWDATA );
+    if( m_rawdata.capacity() < ch::kSizeOfRawData ) m_rawdata.reserve( ch::kSizeOfRawData );
     m_rawdata.clear();
 
     start_load( data );
+#endif
 }
 
 
 //
 // データ受信
 //
-void Login2ch::receive_data( const char* data, size_t size )
+void Login2ch::receive_data( std::string_view buf )
 {
 #ifdef _DEBUG
     std::cout << "Login2ch::receive_data\n";
 #endif
 
-    m_rawdata.append( data, size );
+    m_rawdata.append( buf );
 }
 
 
@@ -139,6 +145,7 @@ void Login2ch::receive_finish()
               << " rawdata size = " << m_rawdata.size() << std::endl;
 #endif
 
+#if 0 // サイトの更新に対応していないためサポートを中止
     bool show_err = true;
 
     if( ! m_rawdata.empty() && get_code() == HTTP_OK ){
@@ -196,6 +203,9 @@ void Login2ch::receive_finish()
         SKELETON::MsgDiag mdiag( nullptr, str_err );
         mdiag.run();  
     }
+#endif
+    SKELETON::MsgDiag mdiag( nullptr, "2chのログインは現在サポート中止しています。" );
+    mdiag.run();
 
     // コアに受信完了を知らせる
     CORE::core_set_command( "login2ch_finished", "" );
