@@ -23,7 +23,7 @@ ConfirmDiag::ConfirmDiag( const std::string& url, const std::string& message )
     const int mrg = 16;
     Gtk::HBox* hbox = Gtk::manage( new Gtk::HBox );
     hbox->pack_start( m_chkbutton, Gtk::PACK_EXPAND_WIDGET, mrg );
-    get_vbox()->pack_start( *hbox, Gtk::PACK_SHRINK );
+    get_content_area()->pack_start( *hbox, Gtk::PACK_SHRINK );
 
     set_title( "投稿確認" );
     show_all_children();
@@ -34,7 +34,7 @@ ConfirmDiag::ConfirmDiag( const std::string& url, const std::string& message )
 ConfirmDiag::~ConfirmDiag() noexcept = default;
 
 
-void ConfirmDiag::slot_switch_page( GtkNotebookPage*, guint page )
+void ConfirmDiag::slot_switch_page( Gtk::Widget*, guint page )
 {
     if( get_notebook().get_nth_page( page ) == get_detail() ){
         get_detail()->set_command( "clear_screen" );
