@@ -40,32 +40,19 @@ using namespace MESSAGE;
 
 
 MessageAdmin::MessageAdmin( const std::string& url )
-    : SKELETON::Admin( url ), m_toolbar( nullptr ), m_toolbar_preview( nullptr ), m_text_message( nullptr )
+    : SKELETON::Admin( url )
 {
     get_notebook()->set_show_tabs( false );
 }
 
 
-MessageAdmin::~MessageAdmin()
-{
-#ifdef _DEBUG
-    std::cout << "MessageAdmin::~MessageAdmin\n";
-#endif 
-
-    if( m_toolbar ) delete m_toolbar;
-    if( m_toolbar_preview ) delete m_toolbar_preview;
-    if( m_text_message ) delete m_text_message;
-}
-
-
-
 void MessageAdmin::show_entry_new_subject( bool show )
 {
     if( m_toolbar ) m_toolbar->show_entry_new_subject( show );
 }
 
 
-std::string MessageAdmin::get_new_subject()
+std::string MessageAdmin::get_new_subject() const
 {
     if( m_toolbar ) return m_toolbar->get_new_subject();
 
@@ -75,9 +62,9 @@ std::string MessageAdmin::get_new_subject()
 
 SKELETON::EditView* MessageAdmin::get_text_message()
 {
-    if( ! m_text_message ) m_text_message = new SKELETON::EditView();
+    if( ! m_text_message ) m_text_message = std::make_unique<SKELETON::EditView>();
 
-    return m_text_message;
+    return m_text_message.get();
 }
 
 
@@ -188,8 +175,8 @@ void MessageAdmin::open_window()
     std::cout << "MessageAdmin::open_window\n";
 #endif
 
-        win = new MESSAGE::MessageWin();
-        set_jdwin( win );
+        set_jdwin( std::make_unique<MESSAGE::MessageWin>() );
+        win = get_jdwin();
         win->pack_remove_end( false, *get_widget() );
         win->show_all();
     }
@@ -309,6 +296,8 @@ void MessageAdmin::open_view( const COMMAND_ARGS& command )
     show_toolbar();
 
     SKELETON::View *view = CORE::ViewFactory( type, url_msg, args );
+    view->set_margin_start( 10 );
+    view->set_margin_end( 10 );
     get_notebook()->append_page( url_msg, *view );
 
     // ウィンドウ表示
@@ -349,12 +338,12 @@ void MessageAdmin::show_toolbar()
     if( ! m_toolbar ){
 
         // 通常のツールバー
-        m_toolbar = new MessageToolBar();
+        m_toolbar = std::make_unique<MessageToolBar>();
         get_notebook()->append_toolbar( *m_toolbar );
         m_toolbar->open_buttonbar();
 
         // プレビュー用のツールバー
-        m_toolbar_preview = new MessageToolBarPreview();
+        m_toolbar_preview = std::make_unique<MessageToolBarPreview>();
         get_notebook()->append_toolbar( *m_toolbar_preview );
         m_toolbar_preview->open_buttonbar();
     }
