@@ -15,11 +15,12 @@
 #include "skeleton/editview.h"
 #include "skeleton/detaildiag.h"
 
-#include "jdlib/miscutil.h"
-#include "jdlib/misctime.h"
-#include "jdlib/misctrip.h"
 #include "jdlib/jdiconv.h"
 #include "jdlib/jdregex.h"
+#include "jdlib/misccharcode.h"
+#include "jdlib/misctime.h"
+#include "jdlib/misctrip.h"
+#include "jdlib/miscutil.h"
 
 #include "dbtree/interface.h"
 
@@ -77,7 +78,7 @@ MessageViewBase::MessageViewBase( const std::string& url )
     m_max_line = DBTREE::line_number( get_url() ) * 2;
     m_max_str = DBTREE::message_count( get_url() );
 
-    m_iconv = std::make_unique<JDLIB::Iconv>( DBTREE::board_charset( get_url() ), "UTF-8" );;
+    m_iconv = std::make_unique<JDLIB::Iconv>( DBTREE::board_encoding( get_url() ), Encoding::utf8 );
 
     m_lng_iconv = m_max_str * 3;
     if( ! m_lng_iconv ) m_lng_iconv = MAX_STR_ICONV;
@@ -891,7 +892,7 @@ void MessageViewBase::slot_switch_page( Gtk::Widget*, guint page )
             std::string trip;
             if( trip_pos != std::string::npos )
             {
-                trip = MISC::get_trip( name_field.substr( trip_pos + 1 ), DBTREE::board_charset( get_url() ) );
+                trip = MISC::get_trip( name_field.substr( trip_pos + 1 ), DBTREE::board_encoding( get_url() ) );
             }
 
             ss << name;
@@ -913,9 +914,8 @@ void MessageViewBase::slot_switch_page( Gtk::Widget*, guint page )
             // 対応していないUnicode文字を文字参照の形式(&#nnnn;)で表示する
             if( DBTREE::get_unicode( get_url() ) == "change" ){
                 // MS932等に無い文字を数値文字参照にするために文字コードを変換する
-                int byte_out;
-                const std::string str_enc = m_iconv->convert( msg.data(), msg.size(), byte_out );
-                msg = MISC::Iconv( str_enc, "UTF-8", DBTREE::board_charset( get_url() ) );
+                const std::string& str_enc = m_iconv->convert( msg.data(), msg.size() );
+                msg = MISC::Iconv( str_enc, Encoding::utf8, DBTREE::board_encoding( get_url() ) );
             }
             else{
                 constexpr bool completely = true;
@@ -994,8 +994,7 @@ void MessageViewBase::show_status()
     }
     else if( m_text_changed )
     {
-        int byte_out;
-        std::string str_enc = m_iconv->convert( message.data(), message.size(), byte_out );
+        const std::string& str_enc = m_iconv->convert( message.data(), message.size() );
         m_lng_str_enc = str_enc.length();
 
         // 特殊文字の文字数を計算
