@@ -218,11 +218,11 @@ void Post::post_msg()
 //
 // ローダからデータを受け取る
 //
-void Post::receive_data( const char* data, size_t size )
+void Post::receive_data( std::string_view buf )
 {
     if( get_code() != HTTP_OK ) return;
 
-    m_rawdata.append( data, size );
+    m_rawdata.append( buf );
 }
 
 
@@ -237,10 +237,8 @@ void Post::receive_finish()
 #endif
 
     {
-        const std::string charset = DBTREE::board_charset( m_url );
-        JDLIB::Iconv libiconv( "UTF-8", charset );
-        int byte_out;
-        m_return_html = libiconv.convert( &*m_rawdata.begin(), m_rawdata.size(), byte_out );
+        JDLIB::Iconv libiconv( Encoding::utf8, DBTREE::board_encoding( m_url ) );
+        libiconv.convert( m_rawdata.data(), m_rawdata.size(), m_return_html );
     }
 
 #ifdef _DEBUG
