@@ -71,8 +71,8 @@ namespace CORE
             m_hbox_selectall.pack_start( m_bt_selectall, Gtk::PACK_SHRINK );
             m_vbox.pack_start( m_hbox_selectall, Gtk::PACK_SHRINK );
 
-            get_vbox()->set_spacing( 8 );
-            get_vbox()->pack_start( m_vbox, Gtk::PACK_SHRINK );
+            get_content_area()->set_spacing( 8 );
+            get_content_area()->pack_start( m_vbox, Gtk::PACK_SHRINK );
 
             set_title( "プライバシー情報の消去" );
             show_all_children();
