@@ -15,6 +15,9 @@
 
 #include "config/globalconf.h"
 
+#include <system_error>
+
+
 CORE::Search_Manager* instance_search_manager = nullptr;
 
 CORE::Search_Manager* CORE::get_search_manager()
@@ -45,6 +48,7 @@ Search_Manager::~Search_Manager()
     set_dispatchable( false );
 
     stop( std::string() );
+    // m_thread.joinable() == true のときスレッドを破棄すると強制終了するため待機処理を入れる
     wait();
 }
 
@@ -70,7 +74,7 @@ bool Search_Manager::search( const std::string& id, const int searchmode, const
 #endif
 
     if( m_searching ) return false;
-    if( m_thread.is_running() ) return false;
+    if( m_thread.joinable() ) return false;
 
     m_searchmode = searchmode;
 
@@ -88,9 +92,12 @@ bool Search_Manager::search( const std::string& id, const int searchmode, const
     // 読み込んでおかないと大量の warning が出る
     if( m_searchmode == SEARCHMODE_ALLLOG ) DBTREE::read_boardinfo_all();
 
-    if( ! m_thread.create( ( STARTFUNC ) launcher, ( void * ) this, JDLIB::NODETACH ) ){
+    try {
+        m_thread = std::thread( &Search_Manager::thread_search, this );
+    }
+    catch( std::system_error& ) {
         MISC::ERRMSG( "Search_Manager::search : could not start thread" );
-        return FALSE;
+        return false;
     }
 
     m_searching = true;
@@ -98,17 +105,6 @@ bool Search_Manager::search( const std::string& id, const int searchmode, const
 }
 
 
-//
-// スレッドのランチャ (static)
-//
-void* Search_Manager::launcher( void* dat )
-{
-    Search_Manager* sm = ( Search_Manager * ) dat;
-    sm->thread_search();
-    return nullptr;
-}
-
-
 //
 // ログ検索実行スレッド
 //
@@ -195,7 +191,7 @@ void Search_Manager::stop( const std::string& id )
 
 void Search_Manager::wait()
 {
-    m_thread.join();
+    if( m_thread.joinable() ) m_thread.join();
 }
 
 
@@ -257,14 +253,16 @@ void Search_Manager::search_fin_title()
         const bool usemigemo = false;
         const bool wchar = false;
         const JDLIB::RegexPattern regexptn( pattern, icase, newline, usemigemo, wchar );
+        const std::string named_caps[3] = { "url", "subject", "number" };
 
         std::size_t offset = 0;
-        while( regex.match( regexptn, source, offset ) ){
+        while( regex.match( regexptn, source, offset, false, false, named_caps ) ){
 
             SEARCHDATA data;
-            data.url_readcgi = DBTREE::url_readcgi( regex.str( 1 ), 0, 0 );
-            data.subject = MISC::html_unescape( regex.str( 2 ) );
-            data.num = std::atoi( regex.str( 3 ).c_str() ); // マッチしていなければ 0 になる
+            // パターン中にグループ名が有れば名前付きキャプチャ、無ければグループ番号で取得する
+            data.url_readcgi = DBTREE::url_readcgi( regex.named_or_num( named_caps[0], 1 ), 0, 0 );
+            data.subject = MISC::html_unescape( regex.named_or_num( named_caps[1], 2 ) );
+            data.num = std::atoi( regex.named_or_num( named_caps[2], 3 ).c_str() ); // マッチしていなければ 0 になる
             data.bookmarked = false;
             data.num_bookmarked = 0;
 
