@@ -13,6 +13,7 @@
 
 #include "control/controlid.h"
 
+#include "command.h"
 #include "dndmanager.h"
 #include "session.h"
 
@@ -26,10 +27,9 @@ DragableNoteBook::DragableNoteBook()
     , m_notebook_toolbar( this )
     , m_notebook_view( this )
     , m_bt_tabswitch( this )
+    , m_show_tabs{ true }
+    , m_show_toolbar{ true }
     , m_page( -1 )
-    , m_dragging_tab( false )
-    , m_dragable( false )
-    , m_down_arrow( nullptr )
 {
     set_spacing( 0 );
 
@@ -48,21 +48,13 @@ DragableNoteBook::DragableNoteBook()
     pack_start( m_hbox_tab, Gtk::PACK_SHRINK );
     pack_start( m_notebook_toolbar, Gtk::PACK_SHRINK );
     pack_start( m_notebook_view );
-    m_show_tabs = true;
-    m_show_toolbar = true;
-
-    memset( &m_alloc_old, 0, sizeof( Alloc_NoteBook ) );
 
     show_all_children();
 }
 
 
-
-DragableNoteBook::~DragableNoteBook()
-{
-    if( m_down_arrow ) delete m_down_arrow;
-}
-
+// メンバーに不完全型のスマートポインターがあるためデストラクタはinlineにできない
+DragableNoteBook::~DragableNoteBook() noexcept = default;
 
 
 //
@@ -108,7 +100,7 @@ void DragableNoteBook::set_scrollable( bool scrollable )
 }
 
 
-int DragableNoteBook::get_n_pages()
+int DragableNoteBook::get_n_pages() const
 {
     return m_notebook_view.get_n_pages();
 }
@@ -120,13 +112,13 @@ Gtk::Widget* DragableNoteBook::get_nth_page( int page_num )
 }
 
 
-int DragableNoteBook::page_num( const Gtk::Widget& child )
+int DragableNoteBook::page_num( const Gtk::Widget& child ) const
 {
     return m_notebook_view.page_num( child );
 }
 
 
-int DragableNoteBook::get_current_page()
+int DragableNoteBook::get_current_page() const
 {
     return m_notebook_view.get_current_page();
 }
@@ -154,7 +146,7 @@ int DragableNoteBook::append_page( const std::string& url, Gtk::Widget& child )
 
     m_bt_tabswitch.show_button();
 
-    SKELETON::TabLabel* tablabel = create_tablabel( url );
+    SKELETON::TabLabel* tablabel = Gtk::manage( create_tablabel( url ) );
     return m_notebook_tab.append_tab( *tablabel );
 }
 
@@ -165,7 +157,7 @@ int DragableNoteBook::insert_page( const std::string& url, Gtk::Widget& child, i
 
     m_bt_tabswitch.show_button();
 
-    SKELETON::TabLabel* tablabel = create_tablabel( url );
+    SKELETON::TabLabel* tablabel = Gtk::manage( create_tablabel( url ) );
     return m_notebook_tab.insert_tab( *tablabel, page );
 }
 
@@ -195,13 +187,10 @@ void DragableNoteBook::set_tab_fulltext( const std::string& str, const int page
 //
 void DragableNoteBook::remove_page( const int page, const bool adjust_tab )
 {
-    SKELETON::TabLabel* tablabel = m_notebook_tab.get_tablabel( page );
-
+    // タブはGtk::manage()の効果でdeleteされる
     m_notebook_tab.remove_tab( page, adjust_tab );
     m_notebook_view.remove_page( page );
 
-    if( tablabel ) delete tablabel;
-
     if( ! get_n_pages() ) m_bt_tabswitch.hide_button();
 }
 
@@ -300,7 +289,7 @@ void DragableNoteBook::set_current_toolbar( const int id_toolbar, SKELETON::View
 }
 
 
-int DragableNoteBook::get_current_toolbar()
+int DragableNoteBook::get_current_toolbar() const
 {
     return m_notebook_toolbar.get_current_page();
 }
@@ -579,7 +568,9 @@ void DragableNoteBook::slot_drag_motion( const int page, const int tab_x, const
     }
     else if( m_dragging_tab ){
 
-        if( ! m_down_arrow ) m_down_arrow = new SKELETON::IconPopup( ICON::DOWN );
+        if( ! m_down_arrow ) m_down_arrow = std::make_unique<SKELETON::IconPopup>( ICON::DOWN );
+        // HACK: サブウインドウにタブ機能がないためメインウインドウに決め打ちしている
+        m_down_arrow->set_transient_for( *CORE::get_mainwindow() );
         m_down_arrow->show();
 
         const int space = 4;
