@@ -44,15 +44,3 @@ void EditColumns::setup_row( Gtk::TreeModel::Row& row,
     row[ m_underline ] = false;
     row[ m_dirid ] = dirid;
 }
-
-
-void EditColumns::copy_row( const Gtk::TreeModel::Row& row_src, Gtk::TreeModel::Row& row_dest )
-{
-    const Glib::ustring url = row_src[ m_url ];
-    const Glib::ustring name = row_src[ m_name ];
-    const Glib::ustring data = row_src[ m_data ];
-    const int type = row_src[ m_type ];
-    const size_t dirid = row_src[ m_dirid ];
-
-    setup_row( row_dest, url, name, data, type, dirid );
-}
