@@ -3,6 +3,7 @@
 #ifndef _EDITVIEWDIALOG_H
 #define _EDITVIEWDIALOG_H
 
+#include <glib/gi18n.h>
 #include <gtkmm.h>
 
 #include "editview.h"
@@ -21,8 +22,8 @@ namespace SKELETON
             m_edit.set_text( str );
             m_edit.set_editable( editable );
 
-            add_button( Gtk::Stock::OK, Gtk::RESPONSE_OK );
-            get_vbox()->pack_start( m_edit  );
+            add_button( g_dgettext( GTK_DOMAIN, "_OK" ), Gtk::RESPONSE_OK );
+            get_content_area()->pack_start( m_edit );
             set_title( title );
             show_all_children();
 
