@@ -6,13 +6,27 @@
 #include "loadable.h"
 
 #include "jdlib/loader.h"
+#include "jdlib/misccharcode.h"
 #include "jdlib/misctime.h"
+#include "jdlib/miscutil.h"
 
 #include "httpcode.h"
 
 using namespace SKELETON;
 
+
+/** @brief HTTPやHTMLからテキストの文字エンコーディングを検出する処理の状態 */
+enum class Loadable::CharsetDetection
+{
+    parse_header, ///< HTTP header を解析する
+    parse_meta,   ///< HTML meta 要素を解析する
+    finished,     ///< 検出を終えた
+};
+
+
 Loadable::Loadable()
+    : m_charset_det{ CharsetDetection::parse_header }
+    , m_encoding{ Encoding::unknown }
 {
     clear_load_data();
 }
@@ -44,6 +58,7 @@ void Loadable::terminate_load()
 // 完全クリア
 void Loadable::clear_load_data()
 {
+    m_charset_det = CharsetDetection::parse_header;
     m_code = HTTP_INIT;
     m_str_code = std::string();
     m_date_modified = std::string();
@@ -96,6 +111,7 @@ bool Loadable::start_load( const JDLIB::LOADERDATA& data )
 
     // 情報初期化
     // m_date_modified, m_cookie は初期化しない
+    m_charset_det = CharsetDetection::parse_header;
     m_code = HTTP_INIT;
     m_str_code = std::string();
     m_location = std::string();
@@ -132,7 +148,39 @@ void Loadable::receive( const char* data, size_t size )
     if( ! m_total_length && m_code != HTTP_INIT ) m_total_length = get_loader_length();
     m_current_length += size;
 
-    receive_data( data, size );
+    if( m_charset_det == CharsetDetection::parse_header ) {
+        const Encoding enc = get_loader_content_charset();
+        if( enc != Encoding::unknown ) {
+            set_encoding( enc );
+            // The HTTP header has a higher precedence than the in-HTML <meta> elements.
+            m_charset_det = CharsetDetection::finished;
+        }
+        else if( m_loader &&
+                 MISC::ascii_ignore_case_find( m_loader->data().contenttype, "html" ) != std::string::npos ) {
+            // If the content MIME type is text/html or application/xhtml+xml,
+            // find charset from <meta> elements.
+            m_charset_det = CharsetDetection::parse_meta;
+        }
+        else {
+            m_charset_det = CharsetDetection::finished;
+        }
+    }
+    if( m_charset_det == CharsetDetection::parse_meta ) {
+        std::string buf( data, size );
+        const std::string charset = MISC::parse_charset_from_html_meta( buf );
+        if( ! charset.empty() ) {
+            const Encoding enc = MISC::encoding_from_web_charset( charset );
+            if( enc != Encoding::unknown ) set_encoding( enc );
+            m_charset_det = CharsetDetection::finished;
+        }
+        else if( m_current_length >= 1024 ) {
+            // <meta> elements which declare a character encoding must be located
+            // entirely within the first 1024 bytes of the document.
+            m_charset_det = CharsetDetection::finished;
+        }
+    }
+
+    receive_data( std::string_view{ data, size } );
 }
 
 
@@ -166,6 +214,12 @@ void Loadable::callback_dispatch()
     if( ! get_loader_cookies().empty() ) m_cookies = get_loader_cookies();
     if( ! get_loader_location().empty() ) m_location = get_loader_location();
 
+    if( m_charset_det == CharsetDetection::parse_header ) {
+        const Encoding enc = get_loader_content_charset();
+        if( enc != Encoding::unknown ) set_encoding( enc );
+        m_charset_det = CharsetDetection::finished;
+    }
+
 #ifdef _DEBUG
     std::cout << "delete loader\n";
 #endif
@@ -180,6 +234,7 @@ void Loadable::callback_dispatch()
     std::cout << "location = " << m_location << std::endl;
     std::cout << "total_length = " << m_total_length << std::endl;
     std::cout << "current length = " << m_current_length << std::endl;
+    std::cout << "charset = " << MISC::encoding_to_cstr( get_encoding() ) << std::endl;
 #endif
 
     receive_finish();
@@ -243,3 +298,22 @@ size_t Loadable::get_loader_length() const
 
     return m_loader->data().length;
 }
+
+
+/** @brief HTTP header Content-Type から文字エンコーディング情報を取得する
+ *
+ * @return 文字エンコーディングの列挙型
+ * @retval Encoding::unknown エンコーディング情報が見つからない、またはJDimでは処理しないエンコーディングだった
+ */
+Encoding Loadable::get_loader_content_charset() const
+{
+    if( m_loader ) {
+        const std::string& contenttype = m_loader->data().contenttype;
+        const std::size_t pos = contenttype.find( "charset=" );
+        if( pos != std::string::npos ){
+            const std::string raw_charset = MISC::utf8_trim( std::string_view{ contenttype }.substr( pos + 8 ) );
+            return MISC::encoding_from_web_charset( raw_charset );
+        }
+    }
+    return Encoding::unknown;
+}
