@@ -13,6 +13,8 @@
 #include "popupwinbase.h"
 #include "view.h"
 
+#include <memory>
+
 
 namespace SKELETON
 {
@@ -21,20 +23,20 @@ namespace SKELETON
         SIG_HIDE_POPUP m_sig_hide_popup;
 
         Gtk::Widget* m_parent;
-        SKELETON::View* m_view;
+        std::unique_ptr<SKELETON::View> m_view;
         int m_mrg_x;  // ポップアップとマウスカーソルの間のマージン(水平方向)
         int m_mrg_y;  // ポップアップとマウスカーソルの間のマージン(垂直方向)
 
     public:
 
         PopupWin( Gtk::Widget* parent, SKELETON::View* view, const int mrg_x, const int mrg_y );
-        ~PopupWin();
+        ~PopupWin() noexcept = default;
 
         // m_view　からの hide シグナルをブリッジする
         SIG_HIDE_POPUP& sig_hide_popup() { return m_sig_hide_popup; }
         void slot_hide_popup(){ m_sig_hide_popup.emit(); }
 
-        SKELETON::View* view(){ return m_view; }
+        SKELETON::View* view(){ return m_view.get(); }
 
         // ポップアップウィンドウの座標と幅と高さを計算して移動とリサイズ
         void slot_resize_popup();
