@@ -4,8 +4,11 @@
 #define _TABLABEL_H
 
 #include <gtkmm.h>
+
+#include <memory>
 #include <string>
 
+
 namespace SKELETON
 {
     // マウス
@@ -38,7 +41,7 @@ namespace SKELETON
         Gtk::Label m_label;
 
         // アイコン画像
-        Gtk::Image* m_image{};
+        std::unique_ptr<Gtk::Image> m_image;
 
         // ラベルに表示する文字列の全体
         std::string m_fulltext;
@@ -46,7 +49,7 @@ namespace SKELETON
       public:
 
         explicit TabLabel( const std::string& url );
-        ~TabLabel();
+        ~TabLabel() noexcept = default;
 
         SIG_TAB_MOTION_EVENT sig_tab_motion_event(){ return  m_sig_tab_motion_event; }
         SIG_TAB_LEAVE_EVENT sig_tab_leave_event(){ return m_sig_tab_leave_event; }
@@ -68,12 +71,12 @@ namespace SKELETON
         Pango::FontDescription get_label_font_description(){
             return m_label.get_pango_context()->get_font_description(); }
 
-        const std::string& get_url(){ return m_url; }
+        const std::string& get_url() const { return m_url; }
 
         void set_dragable( bool dragable, int button );
 
         // 本体の横幅 - ラベルの横幅
-        int get_label_margin();
+        int get_label_margin() const;
 
         // カットしていない全体の文字列
         const std::string& get_fulltext() const { return m_fulltext; }
