@@ -15,10 +15,11 @@
 
 #include <cstring>
 
-enum
-{
-    SIZE_OF_RAWDATA = 1024 * 1024
-};
+
+namespace SKELETON::tl {
+constexpr std::size_t kSizeOfRawData = 256 * 1024;
+}
+
 
 using namespace SKELETON;
 
@@ -44,8 +45,8 @@ TextLoader::~TextLoader()
 void TextLoader::init()
 {
     clear();
-    if( m_rawdata.capacity() < SIZE_OF_RAWDATA ) {
-        m_rawdata.reserve( SIZE_OF_RAWDATA );
+    if( m_rawdata.capacity() < tl::kSizeOfRawData ) {
+        m_rawdata.reserve( tl::kSizeOfRawData );
     }
 }
 
@@ -65,23 +66,29 @@ void TextLoader::reset()
 }
 
 
-//
-// キャッシュからロード
-//
-void TextLoader::load_text()
+/** @brief キャッシュからロード
+ *
+ * @details 読み込んだキャッシュはUTF-8に変換する。
+ * @param[in] encoding キャッシュの文字エンコーディング
+ */
+void TextLoader::load_text( const Encoding encoding )
 {
     if( get_path().empty() ) return;
 
     init();
     set_code( HTTP_INIT );
+    set_encoding( encoding );
     receive_finish();
 }
 
 
-//
-// ダウンロード開始
-//
-void TextLoader::download_text()
+/** @brief ダウンロードを開始する
+ *
+ * @details ダウンロードしたテキストはUTF-8に変換する。
+ * HTTP 304 Not Modified の時はキャッシュから読み込む。
+ * @param[in] encoding ダウンロードしたテキストの文字エンコーディング
+ */
+void TextLoader::download_text( const Encoding encoding )
 {
 #ifdef _DEBUG
     std::cout << "TextLoader::download_text url = " << get_url() << std::endl;
@@ -90,7 +97,7 @@ void TextLoader::download_text()
     if( is_loading() ) return;
     if( m_loaded ) return; // 読み込み済み
     if( ! SESSION::is_online() ){
-        load_text();
+        load_text( encoding );
         return;
     }
 
@@ -101,6 +108,7 @@ void TextLoader::download_text()
     JDLIB::LOADERDATA data;
 
     init();
+    set_encoding( encoding );
     create_loaderdata( data );
     if( data.url.empty() ) return;
     if( ! start_load( data ) ) clear();
@@ -110,14 +118,9 @@ void TextLoader::download_text()
 //
 // ローダよりデータ受信
 //
-void TextLoader::receive_data( const char* data, size_t size )
+void TextLoader::receive_data( std::string_view buf )
 {
-    if( m_rawdata.size() + size < SIZE_OF_RAWDATA ){
-        m_rawdata.append( data, size );
-    }
-    else{
-        MISC::ERRMSG( "TextLoader : received failed ( BOF )\n" );
-    }
+    m_rawdata.append( buf );
 }
 
 
@@ -135,8 +138,8 @@ void TextLoader::receive_finish()
     // 初期化時やnot modifiedの時はキャッシュから読み込み
     if( ! get_path().empty() && ( get_code() == HTTP_INIT || get_code() == HTTP_NOT_MODIFIED ) ){
 
-        m_rawdata.resize( SIZE_OF_RAWDATA );
-        const std::size_t read_size = CACHE::load_rawdata( get_path(), &*m_rawdata.begin(), SIZE_OF_RAWDATA );
+        m_rawdata.resize( tl::kSizeOfRawData );
+        const std::size_t read_size = CACHE::load_rawdata( get_path(), m_rawdata.data(), tl::kSizeOfRawData );
         m_rawdata.resize( read_size );
 
 #ifdef _DEBUG
@@ -172,9 +175,8 @@ void TextLoader::receive_finish()
     set_str_code( std::string() );
 
     // UTF-8に変換しておく
-    JDLIB::Iconv libiconv( "UTF-8", get_charset() );
-    int byte_out;
-    m_data = libiconv.convert( &*m_rawdata.begin(), m_rawdata.size(),  byte_out );
+    JDLIB::Iconv libiconv( Encoding::utf8, get_encoding() );
+    libiconv.convert( m_rawdata.data(), m_rawdata.size(), m_data );
     clear();
 
     receive_cookies();
