@@ -9,9 +9,12 @@
 #ifndef _TEXTLODER_H
 #define _TEXTLODER_H
 
+#include "jdencoding.h"
 #include "loadable.h"
 
 #include <string>
+#include <string_view>
+
 
 namespace JDLIB
 {
@@ -38,17 +41,16 @@ namespace SKELETON
         void reset();
 
         // キャッシュからロード
-        void load_text();
+        void load_text( const Encoding encoding );
 
-        // ダウンロード開始
-        // not modifiedの時はキャッシュから読み込む
-        void download_text();
+        // ダウンロードを開始する
+        // HTTP 304 Not Modified の時はキャッシュから読み込む
+        void download_text( const Encoding encoding );
 
       protected:
 
         virtual std::string get_url() const = 0;
         virtual std::string get_path() const = 0;
-        virtual std::string get_charset() const = 0;
 
         // ロード用データ作成
         virtual void create_loaderdata( JDLIB::LOADERDATA& data ) = 0;
@@ -61,7 +63,7 @@ namespace SKELETON
         void init();
         void clear();
 
-        void receive_data( const char* data, size_t size ) override;
+        void receive_data( std::string_view buf ) override;
         void receive_finish() override;
 
         // HTTP応答ヘッダーのクッキーを取り扱う場合は派生クラスでoverrideする
