@@ -72,8 +72,16 @@ void ToolBar::set_view( SKELETON::View* view )
     set_url( view->get_url() );
 
     // ラベル表示更新
-    set_label( view->get_label() );
-    if( view->is_broken() || view->is_old() || view->is_overflow() ) set_color( view->get_color() );
+    set_label( view->get_label(), view->get_label_use_markup() );
+    if( m_tool_label ) {
+        const std::string& tooltip{ view->get_tooltip_label() };
+        set_tooltip( *m_tool_label,
+                     tooltip.empty() ? view->get_label() : tooltip,
+                     view->get_label_use_markup() );
+    }
+    if( CONFIG::get_change_statitle_color() && ( view->is_broken() || view->is_old() || view->is_overflow() ) ) {
+        set_color( view->get_color() );
+    }
 
     // 閉じるボタンの表示更新
     if( m_button_close ){
@@ -201,15 +209,13 @@ void ToolBar::set_relief()
         for( Gtk::Widget* btn_widget : lists ) {
 
             Gtk::Button* button = nullptr;
-            Gtk::ToolButton* toolbutton = dynamic_cast<Gtk::ToolButton*>( btn_widget );
-            if( toolbutton ) button = dynamic_cast< Gtk::Button* >( toolbutton->get_child() );
-            if( ! button ){
-                Gtk::ToolItem* toolitem = dynamic_cast<Gtk::ToolItem*>( btn_widget );
-                if( toolitem ) button = dynamic_cast< Gtk::Button* >( toolitem->get_child() );
+            if( auto toolitem = dynamic_cast<Gtk::ToolItem*>( btn_widget ); toolitem ) {
+                button = dynamic_cast<Gtk::Button*>( toolitem->get_child() );
             }
             if( button ){
-                if( CONFIG::get_flat_button() ) button->set_relief( Gtk:: RELIEF_NONE );
-                else button->set_relief( Gtk:: RELIEF_NORMAL );
+                auto context = button->get_style_context();
+                if( CONFIG::get_flat_button() ) context->add_class( GTK_STYLE_CLASS_FLAT );
+                else context->remove_class( GTK_STYLE_CLASS_FLAT );
             }
         }
     }
@@ -236,9 +242,10 @@ void ToolBar::pack_transparent_separator()
 //
 // ツールチップ
 //
-void ToolBar::set_tooltip( Gtk::ToolItem& toolitem, const std::string& tip )
+void ToolBar::set_tooltip( Gtk::ToolItem& toolitem, const std::string& tip, const bool use_markup )
 {
-    toolitem.set_tooltip_text( tip );
+    if( use_markup ) toolitem.set_tooltip_markup( tip );
+    else toolitem.set_tooltip_text( tip );
 }
 
 
@@ -285,12 +292,12 @@ Gtk::ToolItem* ToolBar::get_label()
 }
 
 
-void ToolBar::set_label( const std::string& label )
+void ToolBar::set_label( const std::string& label, const bool use_markup )
 {
     if( ! m_ebox_label ) return;
 
     m_label->set_text( label );
-    if( m_tool_label ) set_tooltip( *m_tool_label, label );
+    m_label->set_use_markup( use_markup );
     set_color( "" );
 }
 
@@ -645,7 +652,6 @@ Gtk::ToolButton* ToolBar::get_button_write()
         set_tooltip( *m_button_write, CONTROL::get_label_motions( CONTROL::WriteMessage ) );
 
         m_button_write->signal_clicked().connect( sigc::mem_fun(*this, &ToolBar::slot_clicked_write ) );
-        m_button_write->get_child()->signal_focus_out_event().connect( sigc::mem_fun(*this, &ToolBar::slot_focusout_write_button ) );
     }
 
     return m_button_write;
@@ -672,16 +678,6 @@ void ToolBar::focus_button_write()
 }
 
 
-bool ToolBar::slot_focusout_write_button( GdkEventFocus* )
-{
-#ifdef _DEBUG
-    std::cout << "ToolBar::slot_focusout_write_button\n";
-#endif
-
-    return true;
-}
-
-
 //
 // 再読み込みボタン
 //
