@@ -6,9 +6,9 @@
 #include "admin.h"
 #include "view.h"
 
-#include "history/historymanager.h"
-
 #include "config/globalconf.h"
+#include "history/historymanager.h"
+#include "jdlib/miscgtk.h"
 
 #include "global.h"
 #include "session.h"
@@ -56,7 +56,7 @@ void View::set_url( const std::string& url_new )
 //
 void View::update_url( const std::string& url_old, const std::string& url_new )
 {
-    if( m_url.find( url_old ) != 0 ) return;
+    if( m_url.rfind( url_old, 0 ) != 0 ) return;
 
     std::string url = url_new + m_url.substr( url_old.length() );
 
@@ -167,12 +167,12 @@ bool View::release_keyjump_key( int key )
 
 
 // view 上にマウスポインタがあれば true
-bool View::is_mouse_on_view()
+bool View::is_mouse_on_view() const
 {
     bool ret = false;
 
     int x,y;
-    get_pointer( x, y );
+    MISC::get_pointer_at_window( get_window(), x, y );
     if( x < get_width() && x >= 0 && y < get_height() && y >= 0 ) ret = true;
 
 #ifdef _DEBUG
