@@ -7,6 +7,179 @@
 
 namespace {
 
+class MISC_EncodingToCstrTest : public ::testing::Test {};
+
+TEST_F(MISC_EncodingToCstrTest, unknown)
+{
+    EXPECT_STREQ( "ISO-8859-1", MISC::encoding_to_cstr( Encoding::unknown ) );
+}
+
+TEST_F(MISC_EncodingToCstrTest, ascii)
+{
+    EXPECT_STREQ( "ASCII", MISC::encoding_to_cstr( Encoding::ascii ) );
+}
+
+TEST_F(MISC_EncodingToCstrTest, eucjp)
+{
+    EXPECT_STREQ( "EUC-JP", MISC::encoding_to_cstr( Encoding::eucjp ) );
+}
+
+TEST_F(MISC_EncodingToCstrTest, jis)
+{
+    EXPECT_STREQ( "ISO-2022-JP", MISC::encoding_to_cstr( Encoding::jis ) );
+}
+
+TEST_F(MISC_EncodingToCstrTest, sjis)
+{
+    EXPECT_STREQ( "Shift_JIS", MISC::encoding_to_cstr( Encoding::sjis ) );
+}
+
+TEST_F(MISC_EncodingToCstrTest, utf8)
+{
+    EXPECT_STREQ( "UTF-8", MISC::encoding_to_cstr( Encoding::utf8 ) );
+}
+
+TEST_F(MISC_EncodingToCstrTest, invalid_enum)
+{
+    EXPECT_STREQ( "ISO-8859-1", MISC::encoding_to_cstr( static_cast<Encoding>( -200 ) ) );
+    EXPECT_STREQ( "ISO-8859-1", MISC::encoding_to_cstr( static_cast<Encoding>( 200 ) ) );
+}
+
+
+class MISC_EncodingToIconvCstrTest : public ::testing::Test {};
+
+TEST_F(MISC_EncodingToIconvCstrTest, unknown)
+{
+    EXPECT_STREQ( "ISO-8859-1", MISC::encoding_to_iconv_cstr( Encoding::unknown ) );
+}
+
+TEST_F(MISC_EncodingToIconvCstrTest, ascii)
+{
+    EXPECT_STREQ( "ASCII", MISC::encoding_to_iconv_cstr( Encoding::ascii ) );
+}
+
+TEST_F(MISC_EncodingToIconvCstrTest, eucjp)
+{
+    EXPECT_STREQ( "EUCJP-MS", MISC::encoding_to_iconv_cstr( Encoding::eucjp ) );
+}
+
+TEST_F(MISC_EncodingToIconvCstrTest, jis)
+{
+    EXPECT_STREQ( "ISO-2022-JP", MISC::encoding_to_iconv_cstr( Encoding::jis ) );
+}
+
+TEST_F(MISC_EncodingToIconvCstrTest, sjis)
+{
+    EXPECT_STREQ( "MS932", MISC::encoding_to_iconv_cstr( Encoding::sjis ) );
+}
+
+TEST_F(MISC_EncodingToIconvCstrTest, utf8)
+{
+    EXPECT_STREQ( "UTF-8", MISC::encoding_to_iconv_cstr( Encoding::utf8 ) );
+}
+
+TEST_F(MISC_EncodingToIconvCstrTest, invalid_enum)
+{
+    EXPECT_STREQ( "ISO-8859-1", MISC::encoding_to_iconv_cstr( static_cast<Encoding>( -200 ) ) );
+    EXPECT_STREQ( "ISO-8859-1", MISC::encoding_to_iconv_cstr( static_cast<Encoding>( 200 ) ) );
+}
+
+
+class MISC_EncodingFromSvTest : public ::testing::Test {};
+
+TEST_F(MISC_EncodingFromSvTest, iso_8859_1)
+{
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_sv( "ISO-8859-1" ) );
+}
+
+TEST_F(MISC_EncodingFromSvTest, ascii)
+{
+    EXPECT_EQ( Encoding::ascii, MISC::encoding_from_sv( "ASCII" ) );
+}
+
+TEST_F(MISC_EncodingFromSvTest, eucjp_ms)
+{
+    EXPECT_EQ( Encoding::eucjp, MISC::encoding_from_sv( "EUCJP-MS" ) );
+    EXPECT_EQ( Encoding::eucjp, MISC::encoding_from_sv( "EUC-JP" ) );
+}
+
+TEST_F(MISC_EncodingFromSvTest, iso_2022_jp)
+{
+    EXPECT_EQ( Encoding::jis, MISC::encoding_from_sv( "ISO-2022-JP" ) );
+}
+
+TEST_F(MISC_EncodingFromSvTest, ms932)
+{
+    EXPECT_EQ( Encoding::sjis, MISC::encoding_from_sv( "MS932" ) );
+    EXPECT_EQ( Encoding::sjis, MISC::encoding_from_sv( "Shift_JIS" ) );
+}
+
+TEST_F(MISC_EncodingFromSvTest, utf8)
+{
+    EXPECT_EQ( Encoding::utf8, MISC::encoding_from_sv( "UTF-8" ) );
+}
+
+TEST_F(MISC_EncodingFromSvTest, invalid_encoding_name)
+{
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_sv( "" ) );
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_sv( "INVALID-ENCODING-NAME" ) );
+}
+
+TEST_F(MISC_EncodingFromSvTest, small_case_is_invalid)
+{
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_sv( "iso-8859-1" ) );
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_sv( "ascii" ) );
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_sv( "eucjp-ms" ) );
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_sv( "iso-2022-jp" ) );
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_sv( "ms932" ) );
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_sv( "utf-8" ) );
+}
+
+
+class MISC_EncodingFromWebCharsetTest : public ::testing::Test {};
+
+TEST_F(MISC_EncodingFromWebCharsetTest, iso_8859_1)
+{
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_web_charset( "ISO-8859-1" ) );
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_web_charset( "latin1" ) );
+}
+
+TEST_F(MISC_EncodingFromWebCharsetTest, us_ascii)
+{
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_web_charset( "ASCII" ) );
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_web_charset( "US-ASCII" ) );
+}
+
+TEST_F(MISC_EncodingFromWebCharsetTest, euc_jp)
+{
+    EXPECT_EQ( Encoding::eucjp, MISC::encoding_from_web_charset( "EUC-JP" ) );
+    EXPECT_EQ( Encoding::eucjp, MISC::encoding_from_web_charset( "x-euc-jp" ) );
+}
+
+TEST_F(MISC_EncodingFromWebCharsetTest, iso_2022_jp)
+{
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_web_charset( "ISO-2022-JP" ) );
+}
+
+TEST_F(MISC_EncodingFromWebCharsetTest, shift_jis)
+{
+    EXPECT_EQ( Encoding::sjis, MISC::encoding_from_web_charset( "Shift_JIS" ) );
+    EXPECT_EQ( Encoding::sjis, MISC::encoding_from_web_charset( "Shift-JIS" ) );
+    EXPECT_EQ( Encoding::sjis, MISC::encoding_from_web_charset( "Windows-31J" ) );
+    EXPECT_EQ( Encoding::sjis, MISC::encoding_from_web_charset( "sjis" ) );
+    EXPECT_EQ( Encoding::sjis, MISC::encoding_from_web_charset( "x-sjis" ) );
+
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_web_charset( "MS_Kanji" ) );
+    EXPECT_EQ( Encoding::unknown, MISC::encoding_from_web_charset( "MS932" ) );
+}
+
+TEST_F(MISC_EncodingFromWebCharsetTest, utf8)
+{
+    EXPECT_EQ( Encoding::utf8, MISC::encoding_from_web_charset( "UTF-8" ) );
+    EXPECT_EQ( Encoding::utf8, MISC::encoding_from_web_charset( "utf8" ) );
+}
+
+
 class IsEucjpTest : public ::testing::Test {};
 
 TEST_F(IsEucjpTest, null_data)
